from .. import Provider as BaseProvider


class Provider(BaseProvider):
    jobs = [
        "Adjunct Al Procurorului General",
        "Ambasador",
        "Chestor Parlament",
        "Comandant Unic Aviatie",
        "Comisar General",
        "Comisar General Adjunct",
        "Senator",
        "Guvernator",
        "Presedinte Academie",
        "Presedinte Inalta Curte De Casatie Si Justitie",
        "Presedinte Curte De Apel",
        "Presedinte Curtea De Conturi A Romaniei",
        "Presedinte De Judecatorie",
        "Presedinte Camera Deputatilor",
        "Presedinte Sectie (La Inalta Curte De Casatie Si Justitie, La Curtea De Apel, Tribunale Si Judecatorii)",
        "Presedinte Tribunal",
        "Presedintele Romaniei",
        "Prim-Procuror",
        "Prim-Procuror Adjunct",
        "Prim-Adjunct Al Procurorului General",
        "Prim-Ministru",
        "Procuror General",
        "Procuror Sef De Sectie",
        "Procuror Sef De Sectie Adjunct",
        "Secretar General Al Guvernului",
        "Secretar Parlament",
        "Secretar De Stat",
        "Vicepresedinte (La Inalta Curte De Casatie Si Justitie, Curtea De Apel, Tribunale Si Judecatorii",
        "Inspector-Sef Al Inspectiei Judiciare De Pe Langa Plenul Consiliului Superior Al Magistraturii",
        "Membru Al Consiliului Superior Al Magistraturii",
        "Secretar General Adjunct Al Consiliului Superior Al Magistraturii",
        "Inspector In Cadrul Inspectiei Judiciare Pentru Judecatori/",
        "Inspector General Judecatoresc Sef",
        "Ministru",
        "Ministru Consilier",
        "Ministru De Stat",
        "Ministru Plenipotentiar",
        "Deputat",
        "Presedinte Senat",
        "Subsecretar De Stat",
        "Consilier Diplomatic",
        "Consilier Guvernamental",
        "Consilier Si Consultant Juridic",
        "Consilier Institutii Publice",
        "Consilier Al Ministrului",
        "Consul General",
        "Director Institutie Publica",
        "Director Adjunct Institutie Publica",
        "Director De Cabinet",
        "Director General Institutie Publica",
        "Consilier Economic",
        "Inspector De Stat Sef",
        "Inspector-Sef In Administratia Publica",
        "Magistrat-Asistent-Sef",
        "Notar-Sef",
        "Notar-Sef Adjunct",
        "Secretar-Sef Notariat",
        "Prefect",
        "Secretar General",
        "Sef Birou Institutie Publica",
        "Sef Cabinet",
        "Sef Birou Senatorial",
        "Sef Departament",
        "Sef Protocol De Stat",
        "Sef Serviciu Institutie Publica",
        "Subprefect",
        "Viceguvernator",
        "Presedinte Institutie Publica",
        "Consilier Prezidential",
        "Consilier Parlamentar",
        "Vicepresedinte Institutie Publica",
        "Atasat Diplomatic",
        "Consul",
        "Secretar Diplomatic",
        "Viceconsul",
        "Consultant Prezidential Si Guvernamental",
        "Secretar General Academie",
        "Primar",
        "Secretar Primarie, Prefectura",
        "Viceprimar",
        "Consilier Organizatie Politica",
        "Presedinte Organizatie Politica",
        "Vicepresedinte Organizatie Politica",
        "Secretar Organizatie Politica",
        "Conducator De Asociatii, Filiale Si Organizatii Obstesti",
        "Loctiitor Al Conducatorului De Asociatii, Filiale Si Organizatii Obstesti",
        "Secretar Si Secretar Adjunct Ai Asociatiilor, Filialelor Si Organizatiilor Obstesti",
        "Presedinte Organizatie Sindicala",
        "Vicepresedinte Organizatie Sindicala",
        "Secretar Organizatie Sindicala",
        "Delegat Sindical",
        "Presedinte Asociatie Nationala Cooperatista",
        "Vicepresedinte Asociatie Nationala Cooperatista",
        "Secretar General Asociatie Nationala Cooperatista",
        "Presedinte Asociatie Teritoriala De Organizatii Cooperatiste",
        "Vicepresedinte Asociatie Teritoriala De Organizatii Cooperatiste",
        "Secretar Asociatie Teritoriala De Organizatii Cooperatiste",
        "Sef Departament Organizatie Sindicala",
        "Presedinte Organizatie Cooperatista",
        "Vicepresedinte Organizatie Cooperatista",
        "Presedinte Asociatie Patronala",
        "Vicepresedinte Asociatie Patronala",
        "Presedinte Organizatie Profesionala Nationala",
        "Vicepresedinte Organizatie Profesionala Nationala",
        "Secretar National Organizatie Profesionala Nationala",
        "Presedinte Organizatie Profesionala, Filiala Judeteana/Municipiu",
        "Vicepresedinte Organizatie Profesionala, Filiala Judeteana/Municipiu",
        "Secretar Organizatie Profesionala, Filiala Judeteana/Municipiu",
        "Consilier Presedinte Organizatie Profesionala Nationala",
        "Consilier Presedinte Organizatie Profesionala, Filiala Judeteana/Municipiu",
        "Sef Departament/Compartiment/Presedinte Comisie Organizatie Profesionala, Filiala Judeteana/Municipiu",
        "Delegat Sindical Local",
        "Conducator De Organizatii Umanitare",
        "Secretar Al Organizatiilor Umanitare",
        "Comandant/Comandant Adjunct Aviatie",
        "Comandant Port, Flota",
        "Decan, Rector, Prorector, Prodecan",
        "Director Societate Comerciala",
        "Director Adjunct Societate Comerciala",
        "Inspector General Scolar",
        "Director Stiintific Cercetare-Dezvoltare",
        "Inspector Sanitar Sef",
        "Medic (Farmacist) Director",
        "Medic (Farmacist) Director Adjunct",
        "Director General Societate Comerciala",
        "Director General Adjunct Societate Comerciala",
        "Director De Program",
        "Director General Regie Autonoma",
        "Director General Adjunct Regie Autonoma",
        "Director Control Risc",
        "Director Comercial",
        "Director Vanzari",
        "Director/Director Adjunct, Inspector-Sef",
        "Director Economic",
        "Director Magazin",
        "Sef Corp Executori Bancari",
        "Director Sucursala",
        "Director Tehnic",
        "Director General Institut National De Cercetaredezvoltare",
        "Director Incubator Tehnologic De Afaceri",
        "Director Departament Cercetare-Dezvoltare",
        "Manager General",
        "Manager",
        "Sef Cancelarie",
        "Director De Societate Comerciala Agricola",
        "Antreprenor In Economia Sociala",
        "Director Resurse Umane",
        "Inspector Scolar General Adjunct",
        "Director Casa Corpului Didactic",
        "Presedinte Banca/Vicepresedinte/Prim-Vicepresedinte",
        "Economist-Sef",
        "Inspector General Vanatoare",
        "Director Executiv Banca/Director/Director Adjunct",
        "Sef Departament Banca/Sef-Adjunct Departament",
        "Sef Proiect Banca",
        "Sef Serviciu/Sef Birou/Banca/Societate De Leasing",
        "Coordonator Compartiment/Colectiv Banca",
        "Dealer-Sef (Arbitragist Banca)",
        "Director Unitate Bancara Operationala/Director Adjunct Unitate Bancara Operationala",
        "Sef Agentie Bancara",
        "Contabil-Sef/Director Financiar/Banca/Societate De Leasing",
        "Director De Arhiva Banca",
        "Director/Director Adjunct Divizie/Directie De Leasing",
        "Director/Director Executiv Conformitate",
        "Coordonator Conformitate",
        "Manager Securitatea Informatiei (Chief Information Security Officer ",
        "Comisar Sef Divizie Garda Financiara",
        "Contabil-Sef",
        "Controlor Financiar",
        "Sef Agentie Cec",
        "Sef Birou/Serviciu/Sectie Circumscriptie Financiara",
        "Sef Birou/Serviciu Financiar-Contabilitate",
        "Manager Financiar",
        "Manager Relatii Financiare Externe",
        "Controlor Revizor Financiar",
        "Sef Birou Calificare Si Recalificare",
        "Sef Birou Pensii",
        "Sef Birou Somaj",
        "Sef Oficiu Somaj",
        "Sef Serviciu Resurse Umane",
        "Sef Serviciu Evaluarea Resurselor De Munca",
        "Manager Resurse Umane",
        "Sef Centru Perfectionare",
        "Sef Birou Organizatie Politica, Obsteasca, Umanitara",
        "Sef Serviciu Organizatie Politica, Obsteasca, Umanitara",
        "Inspector Protectie Civila",
        "Sef Executiv Audit Intern",
        "Sef Obiectiv Servicii De Securitate",
        "Manager De Securitate",
        "Manager Energetic",
        "Manager Informatii Pentru Afaceri",
        "Sef Serviciu",
        "Sef Atelier",
        "Sef Sectie",
        "Sef Birou",
        "Procuror Sef Birou/Serviciu",
        "Sef Birou/Serviciu Administrativ",
        "Registrator Coordonator",
        "Registrator-Sef",
        "Grefier-Sef (Judecatorie, Parchet)",
        "Grefier-Sef De Sectie (Curte De Apel, Tribunal, Parchete)",
        "Prim-Grefier",
        "Sef Laborator Criminalistica",
        "Sef Serviciu Marketing",
        "Sef Birou Marketing",
        "Sef Licitatie",
        "Director Operatii Tranzactii",
        "Sef Casa Compensatie",
        "Sef Agentie Bursiera",
        "Manager Marketing (Tarife, Contracte, Achizitii)",
        "Conducator Firma Mica ",
        "Sef Agentie Reclama Publicitara",
        "Sef Birou Reclama Publicitara",
        "Sef Serviciu Reclama Publicitara",
        "Arhitect-Sef",
        "Geolog-Sef",
        "Secretar Stiintific",
        "Sef Formatie Lucrari Geologice",
        "Sef Formatie Cercetare-Dezvoltare",
        "Meteorolog-Sef",
        "Director Filiala Cercetare-Proiectare",
        "Sef Atelier Editie, Multiplicare, Expeditie",
        "Sef Proiect Cercetare-Proiectare",
        "Sef Sectie Cercetare-Proiectare",
        "Sef Atelier Cercetare-Proiectare",
        "Responsabil Cte (Control Tehnic-Economic) In Cercetare-Proiectare",
        "Director Proiect",
        "Sef Proiect/Program",
        "Inspector-Sef Inspectia Meteorologica Nationala",
        "Hidrometeorolog-Sef",
        "Inginer-Sef Agricultura Si Silvicultura",
        "Medic Veterinar Sef",
        "Sef Centru Protectia Plantelor Si Mediului",
        "Sef Centru Reproductia Si Selectia Animalelor",
        "Sef District, Centru, Ocol Silvic",
        "Sef Circumscriptie Sanitar-Veterinara Si Control Al Alimentelor",
        "Sef Complex Zootehnic",
        "Sef Fazanerie",
        "Sef Ferma Agricola (Agrozootehnica)",
        "Sef Laborator Analize Pedologice",
        "Sef Oficiu Cadastru",
        "Sef Parchet",
        "Sef Pepiniera Silvicola, Pomicola, Viticola",
        "Sef Statie Hidrologica, Meteorologica Si Incubatie",
        "Sef Statie Productie, Exploatare, Intretinere In Agricultura",
        "Sef Statie Vinificatie",
        "Sef Statie Lucrari De Irigatie Si Ameliorare A Solului",
        "Inspector Veterinar Sef",
        "Sef Sectie Mecanizare",
        "Conducator Intreprindere Mica ",
        "Sef Pastravarie",
        "Inginer-Sef Piscicultura Si Vanatoare",
        "Conducator Intreprindere Mica ",
        "Inginer-Sef Industria Prelucratoare",
        "Sef Atelier Industria Prelucratoare",
        "Sef Sector Industria Prelucratoare",
        "Sef Laborator In Industria Prelucratoare",
        "Sef Modul In Industria Prelucratoare",
        "Sef Sectie Industrie Prelucratoare",
        "Sef Serviciu Industrie Prelucratoare",
        "Sef Birou Industrie Prelucratoare",
        "Manager Securitate Instalatii Industria Prelucratoare",
        "Conducator Intreprindere Mica ",
        "Inginer-Sef Industria Extractiva",
        "Sef Atelier Industria Extractiva",
        "Sef Sector Industria Extractiva",
        "Sef Modul In Industria Extractiva",
        "Sef Sectie Industrie Extractiva",
        "Sef Serviciu Industrie Extractiva",
        "Sef Birou Industrie Extractiva",
        "Manager Securitate Instalatii Industria Extractiva",
        "Conducator Intreprindere Mica ",
        "Inginer-Sef Exploatare Nucleara",
        "Inginer-Sef Radioprotectie",
        "Sef Unitati Miniere",
        "Sef Brigada Exploatare Miniera",
        "Inspector-Sef Conservarea Energiei",
        "Sef Centru Prelucrare",
        "Sef Laborator Control Tehnic De Calitate A Combustibilului Nuclear",
        "Sef Serviciu Tehnic Si Componente Nucleare",
        "Sef Serviciu Termochimic",
        "Sef Uzina, Centrala Electrica, Gaze, Apa",
        "Sef Centrala Electrica, Gaze Si Apa",
        "Sef Atelier Reparatii Capitale",
        "Inspector General Industria Petroliera",
        "Sef Formatie Industria Petroliera/Petrochimica",
        "Sef Instalatie Petroliera",
        "Sef Laborator Industria Petroliera",
        "Sef Statie Epurare Ape Reziduale",
        "Supervizor Geolog Si Foraj",
        "Sef Formatie In Industria De Masini Si Echipamente",
        "Sef/Sef Adjunct Statie Electrica",
        "Sef/Sef Adjunct Centru Exploatare Retele Electrice",
        "Sef Dispecer Energetic Central (Dec)",
        "Sef Dispecer Energetic Teritorial (Det)",
        "Sef Formatie La Fabricarea Armamentului Si Munitiei",
        "Sef Schimb",
        "Sef Formatie",
        "Ajutor Sef Brigada In Constructii",
        "Inginer-Sef In Constructii",
        "Conducator Antrepriza Constructii-Montaj",
        "Sef Atelier In Constructii",
        "Sef Brigada Complexa Sau Specializata",
        "Sef Laborator In Constructii",
        "Sef Lot",
        "Sef Santier",
        "Sef Sector (Sectie) Drumuri-Poduri",
        "Sef Sectie Productie, Exploatare, Intretinere, Reparatii In Constructii Si Lucrari Publice",
        "Sef Serviciu In Constructii",
        "Sef Birou In Constructii",
        "Sef Sector Exploatare Imbunatatiri Funciare",
        "Sef Sistem Exploatare Imbunatatiri Funciare",
        "Conducator Intreprindere Mica ",
        "Capitan Sef Port",
        "Comandant Nave Maritime",
        "Comandant Coordonator Grup Mare Pescuit Oceanic",
        "Conducator (Director Si Director Adjunct) Administratia Filiala Dunarea De Jos (Afdj)",
        "Director Zbor",
        "Inginer-Sef Transporturi",
        "Picher Sef District",
        "Revizor General Siguranta Circulatiei",
        "Sef Agentie Navala",
        "Sef Atelier Aeroport",
        "Sef Atelier Transporturi",
        "Sef Autobaza",
        "Sef Birou Aeroport",
        "Sef Birou/Serviciu Relatii Internationale",
        "Sef Birou/Serviciu Transport Maritim Si Fluvial",
        "Sef Coloana Auto",
        "Sef Depou/Adjunct",
        "Sef District Cai Ferate, Poduri, Drumuri",
        "Sef Divizie Cai Ferate",
        "Sef Laborator Aeroport",
        "Sef Port",
        "Sef Regulator Circulatie Cai Ferate",
        "Sef Revizie Locomotive, Automotoare",
        "Sef Revizie Vagoane",
        "Sef Sectie/Adjunct (Sector) Transporturi",
        "Sef Serviciu, Centru, Statie, Aeroport",
        "Sef Serviciu Filiala Administratia Filiala Dunarea De Jos",
        "Sef Statie Cai Ferate",
        "Sef Statie Teleferic",
        "Sef Agentie Pilotaj",
        "Sef Cart",
        "Diriginte Oficiu Transporturi",
        "Sef Garaj",
        "Comandant Instructor",
        "Sef Mecanic Instructor",
        "Sef Mecanic Maritim/Fluvial",
        "Sef Electrician Maritim",
        "Sef Atelier Reparatii",
        "Conducator Activitate De Transport Rutier",
        "Sef Trafic Auto Intern",
        "Sef Trafic Curierat Intern",
        "Sef Departament Logistica",
        "Sef Birou Aprovizionare-Desfacere",
        "Sef Depozit",
        "Sef Serviciu Aprovizionare-Desfacere",
        "Sef Siloz",
        "Sef Statie Uscare-Conditionare Cereale",
        "Manager Achizitii",
        "Manager Farmacii",
        "Manager Aprovizionare",
        "Manager Relatia Cu Furnizorii",
        "Conducator Intreprindere Mica ",
        "Director Centru De Calcul",
        "Sef Oficiu De Calcul",
        "Sef Atelier Informatica",
        "Sef Laborator Informatica",
        "Director Divizie Informatica",
        "Director Departament Informatica",
        "Manager Tehnologia Informatiilor Si Comunicatii",
        "Director Departament Securitate",
        "Conducator De Intreprindere Mica ",
        "Sef Atelier Telecomunicatii",
        "Sef Birou Exploatare Postala",
        "Sef Birou Radiotelecomunicatii",
        "Sef Centrala Telefonica",
        "Sef Centru Control Calitate Emisie Radiofonica",
        "Sef Centru Control Calitate Emisie Televiziune",
        "Sef Centru Control Local Comunicatii",
        "Sef Centru Dirijare Zbor",
        "Sef Centru Postal",
        "Sef Centru (Sectie, Sector) Radiodifuziune",
        "Sef Centru (Sectie, Sector) Telecomunicatii",
        "Sef Centru Zonal Interventii Radiorelee",
        "Sef Centru Zonal De Interventii Translatare Tv",
        "Sef Formatie Comunicatii",
        "Sef Formatie Operationala Telecomunicatii",
        "Sef Laborator Masuratori Telecomunicatii",
        "Sef Laborator Radioteleviziune",
        "Sef Laborator Telecomunicatii",
        "Sef Lot Telecomunicatii",
        "Sef Retea Telecomunicatii",
        "Sef Serviciu Control Zonal Comunicatii",
        "Sef Serviciu Exploatare Postala",
        "Sef Serviciu Informare Zbor",
        "Sef Serviciu Navigatie",
        "Sef Serviciu Radiotelecomunicatii",
        "Sef Statie Comunicatii Prin Satelit",
        "Sef Statie Radiorelee",
        "Sef Statie Televiziune",
        "Sef Studio",
        "Telefonist-Sef",
        "Telegrafist-Sef",
        "Sef Oficiu Zonal Posta",
        "Sef Oficiu Special Posta",
        "Diriginte Oficiu Telecomunicatii",
        "Sef Turn Telecomunicatii",
        "Sef Statie Radiotelegrafie (Rtg)",
        "Sef Centru National De Telecomunicatii Aeronautice Aviatie Civila",
        "Conducator Intreprindere Mica ",
        "Asistent Medical Sef",
        "Biochimist Sef Sectie, Laborator",
        "Biolog Sef Sectie, Laborator",
        "Chimist Sef Sectie, Laborator",
        "Farmacist Sef Sectie, Laborator",
        "Farmacist Diriginte",
        "Laborant Medical Sef",
        "Medic-Sef (Policlinica, Statie De Salvare, Centru De Recoltare Sange)",
        "Medic Sef Sectie, Laborator",
        "Moasa-Sefa",
        "Oficiant Medical Sef",
        "Psiholog Sef Sectie, Laborator",
        "Sora Medicala Sefa",
        "Tehnician Sanitar Sef",
        "Sef Serviciu De Reintegrare Sociala Si Supraveghere",
        "Conducator De Intreprindere Mica ",
        "Conducator Tabara Scolara",
        "Director Unitate De Invatamant",
        "Secretar Stiintific Invatamant, Cercetare",
        "Sef Lectorat",
        "Sef Catedra",
        "Conducator De Intreprindere Mica ",
        "Director Palate Si Cluburi Ale Elevilor",
        "Sef Serviciu/Sef Birou Asigurari",
        "Sef Serviciu/Sef Birou Daune",
        "Sef Expozitii Si Targuri",
        "Sef Vama",
        "Inginer-Sef Intreprinderi De Reparatii Obiecte De Uz Casnic, Curatatorii Si Alte Servicii Pentru Populatie",
        "Sef Atelier Reparatii Obiecte De Uz Casnic, Curatatorii Si Alte Servicii Pentru Populatie",
        "Sef Centru Reparatii",
        "Sef Centru Dezinfectie, Deratizare Si Dezinsectie",
        "Coordonator Presa",
        "Librar-Sef",
        "Conducator Intreprindere Mica ",
        "Redactor-Sef Presa, Editura",
        "Secretar General Agentie Presa, Editura",
        "Secretar General Redactie",
        "Sef Birou Exploatare, Coordonare Presa",
        "Sef Birou Redactie",
        "Sef Birou Relatii Unitati Presa",
        "Sef Oficiu Juridic",
        "Sef Oficiu, Serviciu, Sectie, Redactie",
        "Conducator Intreprindere Mica ",
        "Sef Complex Hotelier",
        "Sef Unitate Balneoclimaterica",
        "Administrator Hotel",
        "Director De Hotel",
        "Director De Motel",
        "Director De Hotel Pentru Tineret",
        "Director De Camping",
        "Director De Sat De Vacanta",
        "Director De Popas Turistic",
        "Director Restaurant",
        "Director Rotiserie",
        "Director Crama",
        "Director Braserie",
        "Director Berarie",
        "Director Gradina De Vara",
        "Director Bar",
        "Director Cafenea",
        "Director Disco-Bar",
        "Director Unitati Tip Fast-Food",
        "Director Cofetarie, Patiserie",
        "Director De Club (Hotelier)",
        "Director De Cazare",
        "Sef Restaurant",
        "Director De Departament Alimentatie",
        "Director De Departament Catering",
        "Presedinte Cooperativa De Consum",
        "Sef Baza Receptie",
        "Sef Serviciu Comert Cu Ridicata Si Cu Amanuntul",
        "Sef Birou Comert Cu Ridicata Si Cu Amanuntul",
        "Vicepresedinte Cooperativa De Consum",
        "Sef Statie Peco",
        "Sef Departament Marfuri Alimentare/Nealimentare",
        "Manager De Zona",
        "Inginer Sef Firme De Afaceri Si Alte Servicii Comerciale",
        "Sef Agentie Comerciala",
        "Conducator Intreprindere Mica ",
        "Antrenor Federatie Sportiva",
        "Comandant Aeroclub",
        "Consilier Teritorial Sef Inspectoratul Pentru Cultura",
        "Director Asezamant Cultural",
        "Manager Al Organizatiei Culturale",
        "Presedinte Federatie Sportiva",
        "Presedinte Complex, Club Sportiv",
        "Secretar General Federatie Sport",
        "Sef Agentie Concursuri Hipice",
        "Sef Productie Film",
        "Sef Sectie Productie Film",
        "Sef Atelier Productie Film",
        "Sef Oficiu Interjudetean Difuzare Film",
        "Conducator De Intreprindere Mica ",
        "Sef Atelier Decorator",
        "Sef Agentie/Oficiu Turism",
        "Sef Unitate Elementara De Lucru",
        "Sef Atelier Presa",
        "Sef Laborator Conservare-Restaurare Opere De Arta",
        "Sef Serviciu Control Tehnic Presa",
        "Conducator De Intreprindere Mica ",
        "Manager In Activitatea De Turism",
        "Director De Agentie De Turism Touroperatoare/ Detailista/Filiala/Sucursala",
        "Director Centru Informare Turistica",
        "Director De Departament Organizare Evenimente",
        "Conducator De Pensiune Turistica (Rurala, Agroturistica, Montana)",
        "Sef Serviciu Statie, Tura Meteo",
        "Sef Centru Meteo Aeronautic",
        "Sef Birou/Statie/Tura Meteo Aeronautic/De Aerodrom",
        "Sef Centru National Pentru Protectia Meteorologica A Navigatiei Aeriene",
        "Sef Echipa Interventii Si Supraveghere Echipamente In Serviciile De Trafic Aerian",
        "Fizician",
        "Cercetator In Fizica",
        "Asistent De Cercetare In Fizica",
        "Cercetator In Fizica-Chimie",
        "Asistent De Cercetare In Fizica-Chimie",
        "Cercetator In Fizica Tehnologica",
        "Asistent De Cercetare In Fizica Tehnologica",
        "Cercetator In Astronomie",
        "Asistent De Cercetare In Astronomie",
        "Cercetator De Aeronave",
        "Inginer De Cercetare De Aeronave",
        "Asistent De Cercetare De Aeronave",
        "Cercetator In Constructii Aerospatiale",
        "Inginer De Cercetare In Constructii Aerospatiale",
        "Asistent De Cercetare In Constructii Aerospatiale",
        "Meteorolog (Studii Superioare)",
        "Meteorolog Previzionist",
        "Climatolog",
        "Meteorolog Aeronautic",
        "Consilier/Expert In Meteorologie Si Domenii Conexe",
        "Asistent Meteorolog",
        "Meteorolog Aeronautic Prognozist",
        "Coordonator Interventii Active In Atmosfera",
        "Cercetator In Meteorologie",
        "Asistent De Cercetare In Meteorologie",
        "Chimist",
        "Consilier Chimist",
        "Expert Chimist",
        "Inspector De Specialitate Chimist",
        "Referent De Specialitate Chimist",
        "Cercetator In Chimie",
        "Asistent De Cercetare In Chimie",
        "Cercetator In Biochimie Tehnologica",
        "Asistent De Cercetare In Biochimie Tehnologica",
        "Cercetator In Chimie Fizica",
        "Asistent De Cercetare In Chimie Fizica",
        "Consilier Geolog",
        "Expert Geolog",
        "Inspector De Specialitate Geolog",
        "Referent De Specialitate Geolog",
        "Consilier Geofizician",
        "Expert Geofizician",
        "Inspector De Specialitate Geofizician",
        "Referent De Specialitate Geofizician",
        "Consilier Hidrogeolog",
        "Expert Hidrogeolog",
        "Inspector De Specialitate Hidrogeolog",
        "Referent De Specialitate Hidrogeolog",
        "Consilier Hidrolog",
        "Expert Hidrolog",
        "Inspector De Specialitate Hidrolog",
        "Referent De Specialitate Hidrolog",
        "Consilier Pedolog",
        "Expert Pedolog",
        "Inspector De Specialitate Pedolog",
        "Referent De Specialitate Pedolog",
        "Inginer Geolog",
        "Geolog",
        "Geofizician",
        "Hidrolog",
        "Pedolog",
        "Cercetator In Geologie",
        "Asistent De Cercetare In Geologie",
        "Cercetator In Geologie Tehnica",
        "Asistent De Cercetare In Geologie Tehnica",
        "Cercetator In Geofizica",
        "Asistent De Cercetare In Geofizica",
        "Cercetator In Mineralogia Tehnica Si Experimentala",
        "Asistent De Cercetare In Mineralogia Tehnica Si Experimentala",
        "Cercetator In Geochimie",
        "Asistent De Cercetare In Geochimie",
        "Cercetator In Geologie Petroliera",
        "Asistent De Cercetare In Geologie Petroliera",
        "Cercetator In Geodezie",
        "Inginer De Cercetare In Geodezie",
        "Asistent De Cercetare In Geodezie",
        "Cercetator In Cadastru",
        "Inginer De Cercetare In Cadastru",
        "Asistent De Cercetare In Cadastru",
        "Consilier Matematician",
        "Expert Matematician",
        "Inspector De Specialitate Matematician",
        "Referent De Specialitate Matematician",
        "Consilier Actuar",
        "Expert Actuar",
        "Inspector De Specialitate Actuar",
        "Referent De Specialitate Actuar",
        "Matematician",
        "Actuar (Studii Superioare)",
        "Consilier Statistician",
        "Expert Statistician",
        "Inspector De Specialitate Statistician",
        "Referent De Specialitate Statistician",
        "Cercetator In Matematica",
        "Asistent De Cercetare In Matematica",
        "Cercetator In Matematica Mecanica",
        "Asistent De Cercetare In Matematica-Mecanica",
        "Cercetator In Matematica Aplicata",
        "Asistent De Cercetare In Matematica Aplicata",
        "Cercetator In Matematica-Fizica",
        "Asistent De Cercetare In Matematica-Fizica",
        "Cercetator In Matematica Informatica",
        "Asistent De Cercetare In Matematica-Informatica",
        "Cercetator In Statistica",
        "Asistent De Cercetare In Statistica",
        "Cercetator In Demografie",
        "Asistent De Cercetare In Demografie",
        "Consilier Biolog",
        "Expert Biolog",
        "Inspector De Specialitate Biolog",
        "Referent De Specialitate Biolog",
        "Consilier Botanist",
        "Expert Botanist",
        "Inspector De Specialitate Botanist",
        "Referent De Specialitate Botanist",
        "Consilier Zoolog",
        "Expert Zoolog",
        "Inspector De Specialitate Zoolog",
        "Referent De Specialitate Zoolog",
        "Consilier Ecolog",
        "Biolog",
        "Zoolog",
        "Botanist",
        "Consilier Bacteriolog",
        "Expert Bacteriolog",
        "Inspector De Specialitate Bacteriolog",
        "Referent De Specialitate Bacteriolog",
        "Consilier Biochimist",
        "Expert Biochimist",
        "Inspector De Specialitate Biochimist",
        "Referent De Specialitate Biochimist",
        "Consilier Farmacolog",
        "Expert Farmacolog",
        "Inspector De Specialitate Farmacolog",
        "Referent De Specialitate Farmacolog",
        "Consilier Microbiolog",
        "Expert Microbiolog",
        "Inspector De Specialitate Microbiolog",
        "Referent De Specialitate Microbiolog",
        "Farmacolog",
        "Bacteriolog",
        "Microbiolog",
        "Cercetator In Biologie",
        "Asistent De Cercetare In Biologie",
        "Cercetator In Microbiologie-Bacteriologie",
        "Asistent De Cercetare In Microbiologie-Bacteriologie",
        "Cercetator In Biologie Chimie",
        "Asistent De Cercetare In Biologie Chimie",
        "Cercetator In Botanica",
        "Asistent De Cercetare In Botanica",
        "Cercetator In Domeniul Zoologic",
        "Asistent De Cercetare In Domeniul Zoologic",
        "Cercetator In Ecologie Si Protectia Mediului",
        "Asistent De Cercetare In Ecologie Si Protectia Mediului",
        "Cercetator In Ingineria Genetica",
        "Asistent De Cercetare In Ingineria Genetica",
        "Consilier Inginer Agronom",
        "Expert Inginer Agronom",
        "Inspector De Specialitate Inginer Agronom",
        "Referent De Specialitate Inginer Agronom",
        "Consilier Inginer Horticol",
        "Expert Inginer Horticol",
        "Inspector De Specialitate Inginer Horticol",
        "Referent De Specialitate Inginer Horticol",
        "Consilier Inginer Zootehnist",
        "Expert Inginer Zootehnist",
        "Inspector De Specialitate Inginer Zootehnist",
        "Referent De Specialitate Inginer Zootehnist",
        "Subinginer Agronom",
        "Subinginer Zootehnist",
        "Inginer Tehnolog In Zootehnie",
        "Proiectant Inginer In Agricultura",
        "Proiectant Inginer In Zootehnie",
        "Proiectant Inginer In Silvicultura",
        "Consilier Inginer Silvic",
        "Expert Inginer Silvic",
        "Inspector De Specialitate Inginer Silvic",
        "Referent De Specialitate Inginer Silvic",
        "Inginer Imbunatatiri Funciare",
        "Inginer/Subinginer Silvic",
        "Inginer Agronom",
        "Inginer Zootehnist",
        "Consultant Tehnic In Productia De Cereale, Plante Tehnice Si Furaje",
        "Subinginer Imbunatatiri Funciare",
        "Agent Agricol",
        "Brigadier Silvic",
        "Padurar",
        "Tehnician Agronom ",
        "Tehnician Zootehnist ",
        "Tehnician Silvic ",
        "Clasificator Carcase",
        "Operator De Insamantari Artificiale La Animale",
        "Administrator Bunuri Agricole",
        "Consultant Afaceri In Agricultura",
        "Cercetator In Agricultura",
        "Inginer De Cercetare In Agricultura",
        "Asistent De Cercetare In Agricultura",
        "Inginer De Cercetare In Pedologie-Agrochimie",
        "Asistent De Cercetare In Pedologie-Agrochimie",
        "Cercetator In Pedologie-Agrochimie",
        "Cercetator In Horticultura",
        "Inginer De Cercetare In Horticultura",
        "Asistent De Cercetare In Horticultura",
        "Cercetator In Agromontanologie",
        "Inginer De Cercetare In Agromontanologie",
        "Asistent De Cercetare In Agromontanologie",
        "Cercetator In Silvicultura",
        "Inginer De Cercetare In Silvicultura",
        "Asistent De Cercetare In Silvicultura",
        "Cercetator In Zootehnie",
        "Asistent De Cercetare In Zootehnie",
        "Cercetator In Biotehnologie Pentru Agricultura",
        "Asistent De Cercetare In Biotehnologie Pentru Agricultura",
        "Expert Ecolog",
        "Inspector De Specialitate Ecolog",
        "Referent De Specialitate Ecolog",
        "Inginer Ecolog",
        "Ecolog",
        "Inginer Confectii Piele Si Inlocuitori",
        "Inginer Textile, Pielarie",
        "Inginer Tricotaje, Confectii",
        "Subinginer Textile, Pielarie",
        "Proiectant Inginer Textile, Pielarie",
        "Consilier Inginer Textile, Pielarie",
        "Expert Inginer Textile, Pielarie",
        "Inspector Specialitate Inginer Textile, Pielarie",
        "Referent De Specialitate Inginer Textile, Pielarie",
        "Conceptor/Conceptor Cao",
        "Specialist Incercari Componente Vehicule/Grup Motopropulsor/Optimizare Energetica/Sisteme De Masurare",
        "Specialist Documentatie Studii",
        "Instructor Sistem De Productie",
        "Metodist",
        "Responsabil Afacere",
        "Manager De Cladire",
        "Inginer Industrializarea Lemnului",
        "Subinginer Industrializarea Lemnului",
        "Consilier Inginer Industrializarea Lemnului",
        "Expert Inginer Industrializarea Lemnului",
        "Inspector De Specialitate Inginer Industrializarea Lemnului",
        "Referent De Specialitate Inginer Industrializarea Lemnului",
        "Cercetator In Tehnologia Prelucrarii Produselor Agricole",
        "Inginer De Cercetare In Tehnologia Prelucrarii Produselor Agricole",
        "Asistent De Cercetare In Tehnologia Prelucrarii Produselor Agricole",
        "Cercetator In Pescuit Si Acvacultura",
        "Inginer De Cercetare In Pescuit Si Acvacultura",
        "Asistent De Cercetare In Pescuit Si Acvacultura",
        "Specialist In Domeniul Calitatii",
        "Auditor In Domeniul Calitatii",
        "Analist Calitate",
        "Analist Masuratori Metrologice",
        "Analist Studiul Materialelor",
        "Consultant Sistem De Calitate",
        "Logistician Gestiune Flux",
        "Programator Fabricatie/Lansator Fabricatie",
        "Documentarist Ordonantare Logistica",
        "Auditor Energetic Pentru Cladiri",
        "Inginer Constructii Civile, Industriale Si Agricole",
        "Subinginer Constructii Civile, Industriale Si Agricole",
        "Inginer Instalatii Pentru Constructii",
        "Inginer Cai Ferate, Drumuri Si Poduri",
        "Inginer Constructii Hidrotehnice",
        "Inginer Constructor Instalatii",
        "Proiectant Inginer Instalatii",
        "Proiectant Inginer Constructii",
        "Consilier Inginer Constructii",
        "Expert Inginer Constructii",
        "Inspector De Specialitate Inginer Constructii",
        "Referent De Specialitate Inginer Constructii",
        "Conducator De Lucrari Civile",
        "Diriginte Santier (Studii Superioare)",
        "Cercetator In Constructii Civile, Industriale Si Agricole",
        "Inginer De Cercetare In Constructii Civile, Industriale Si Agricole",
        "Asistent De Cercetare In Constructii Civile, Industriale Si Agricole",
        "Cercetator In Constructii De Cai Ferate, Drumuri Si Poduri",
        "Inginer De Cercetare In Constructii De Cai Ferate, Drumuri Si Poduri",
        "Asistent De Cercetare In Constructii De Cai Ferate, Drumuri Si Poduri",
        "Cercetator In Constructii Hidrotehnice",
        "Inginer De Cercetare In Constructii Hidrotehnice",
        "Asistent De Cercetare In Constructii Hidrotehnice",
        "Inginer De Cercetare In Ingineria Sanitara Si Protectia Mediului",
        "Cercetator In Constructii Miniere",
        "Inginer De Cercetare In Constructii Miniere",
        "Asistent De Cercetare In Constructii Miniere",
        "Cercetator In Instalatii",
        "Inginer De Cercetare In Instalatii",
        "Asistent De Cercetare In Instalatii",
        "Cercetator In Stiinta Si Ingineria Materialelor Oxidice",
        "Inginer De Cercetare In Ingineria Materialelor Oxidice",
        "Asistent De Cercetare In Ingineria Materialelor Oxidice",
        "Cercetator In Centrale Hidroelectrice In Ingineria Mediului",
        "Inginer De Cercetare In Centrale Hidroelectrice In Ingineria Mediului",
        "Asistent De Cercetare In Centrale Hidroelectrice In Ingineria Mediului",
        "Inginer Mecanic",
        "Subinginer Mecanic",
        "Inginer Electromecanic Minier",
        "Inginer Material Rulant Cale Ferata",
        "Inginer Mecanica Agricola",
        "Inginer Aviatie",
        "Inginer Nave",
        "Inginer Masini-Unelte",
        "Inginer Mecanica Fina",
        "Inginer Masini Termice",
        "Inginer Masini Hidraulice Si Pneumatice",
        "Inginer Autovehicule Rutiere",
        "Inginer Mecanic Utilaj Tehnologic Chimic",
        "Inginer Mecanic Utilaj Tehnologic Petrolier",
        "Inginer Mecanic Utilaj Tehnologic Masini Agricole",
        "Inginer Mecanic Utilaj Tehnologic Textil",
        "Inginer Mecanic Utilaj Tehnologic Pentru Constructii",
        "Inginer Mecanic Utilaj Tehnologic Pentru Prelucrare La Cald",
        "Inginer Mecanic Masini Instalatii Miniere",
        "Subinginer Mecanic Tehnologia Constructiilor De Masini",
        "Subinginer Mecanic Utilaje Si Tehnica Sudurii",
        "Subinginer Mecanic, Mecanica Fina",
        "Subinginer Mecanic Material Rulant De Cale Ferata",
        "Subinginer Mecanic Mecanica Agricola",
        "Subinginer Mecanic Utilaj Tehnologic Pentru Chimie",
        "Subinginer Mecanic Utilaje Pentru Constructii",
        "Subinginer Mecanic Avioane Si Motoare De Aviatie",
        "Subinginer Mecanic Constructii Corp De Nava",
        "Subinginer Mecanic Instalatii Navale De Bord",
        "Subinginer Mecanic Automobile",
        "Subinginer Mecanic Utilaje Pentru Industria Lemnului",
        "Subinginer Mecanic Utilaje Pentru Materiale De Constructie",
        "Consilier Inginer Mecanic",
        "Expert Inginer Mecanic",
        "Inspector De Specialitate Inginer Mecanic",
        "Referent De Specialitate Inginer Mecanic",
        "Proiectant Inginer Aeronave",
        "Proiectant Inginer Mecanic",
        "Inginer Pilot De Incercare",
        "Subinginer Proiectant Mecanic",
        "Specialist Reglementari/Carti De Identitate Vehicule/Verificari Tehnice Inmatriculare/Inspectii Tehnice",
        "Specialist Prestatii Vehicule",
        "Specialist Mentenanta Mecanica Echipamente Industriale",
        "Inginer/Subinginer Tehnolog Prelucrari Mecanice",
        "Inginer Tehnolog In Fabricarea Armamentului Si Munitiei",
        "Subinginer Tehnolog In Fabricarea Armamentului Si Munitiei",
        "Inginer Pentru Protectia Navigatiei Aeriene (Comunicatii, Navigatie, Supraveghere)",
        "Cercetator In Sisteme De Propulsie",
        "Inginer De Cercetare In Sisteme De Propulsie",
        "Asistent De Cercetare In Sisteme De Propulsie",
        "Cercetator In Echipamente Si Instalatii De Bord",
        "Inginer De Cercetare In Echipamente Si Instalatii De Bord",
        "Asistent De Cercetare In Echipamente Si Instalatii De Bord",
        "Cercetator In Masini Si Echipamente Termice",
        "Inginer De Cercetare In Masini Si Echipamente Termice",
        "Asistent De Cercetare In Masini Si Echipamente Termice",
        "Cercetator In Masini Hidraulice Si Pneumatice",
        "Inginer De Cercetare In Masini Hidraulice Si Pneumatice",
        "Asistent De Cercetare In Masini Hidraulice Si Pneumatice",
        "Cercetator In Echipamente De Proces",
        "Inginer De Cercetare In Echipamente De Proces",
        "Asistent De Cercetare In Echipamente De Proces",
        "Cercetator In Mecanica Fina",
        "Inginer De Cercetare In Mecanica Fina",
        "Asistent De Cercetare In Mecanica Fina",
        "Cercetator In Tehnologia Constructiilor De Masini",
        "Inginer De Cercetare In Tehnologia Constructiilor De Masini",
        "Asistent De Cercetare In Tehnologia Constructiilor De Masini",
        "Cercetator In Constructii De Masini Agricole",
        "Inginer De Cercetare In Constructii De Masini Agricole",
        "Asistent De Cercetare In Constructii De Masini Agricole",
        "Cercetator In Autovehicule Rutiere",
        "Inginer De Cercetare In Autovehicule Rutiere",
        "Asistent De Cercetare In Autovehicule Rutiere",
        "Cercetator In Utilaje Si Instalatii Portuare",
        "Inginer De Cercetare In Utilaje Si Instalatii Portuare",
        "Asistent De Cercetare In Utilaje Si Instalatii Portuare",
        "Cercetator In Utilaje Si Tehnologia Ambalarii",
        "Inginer De Cercetare In Utilaje Si Tehnologia Ambalarii",
        "Asistent De Cercetare In Utilaje Si Tehnologia Ambalarii",
        "Cercetator In Creatia Tehnica In Constructia De Masini",
        "Inginer De Cercetare In Creatia Tehnica In Constructia De Masini",
        "Asistent De Cercetare In Creatia Tehnica In Constructia De Masini",
        "Cercetator In Masini Si Instalatii Mecanice",
        "Inginer De Cercetare In Masini Si Instalatii Mecanice",
        "Asistent De Cercetare In Masini Si Instalatii Mecanice",
        "Cercetator In Instalatii Si Utilaje Pentru Transportul Si Depozitarea Produselor Petroliere",
        "Inginer Petrochimist",
        "Subinginer Petrochimist",
        "Proiectant Inginer Chimist",
        "Consilier Inginer Chimist",
        "Expert Inginer Chimist",
        "Inspector De Specialitate Inginer Chimist",
        "Referent De Specialitate Inginer Chimist",
        "Consilier Inginer Petrochimist",
        "Expert Inginer Petrochimist",
        "Inspector De Specialitate Inginer Petrochimist",
        "Referent De Specialitate Petrochimist",
        "Biochimist",
        "Inginer Chimist",
        "Inginer In Industria Alimentara",
        "Subinginer In Industria Alimentara",
        "Proiectant Inginer Produse Alimentare",
        "Consilier Inginer Industria Alimentara",
        "Expert Inginer Industria Alimentara",
        "Inspector De Specialitate Inginer Industria Alimentara",
        "Referent De Specialitate Inginer Industria Alimentara",
        "Cercetator In Tehnologia Substantelor Anorganice",
        "Inginer De Cercetare In Tehnologia Substantelor Anorganice",
        "Asistent De Cercetare In Tehnologia Substantelor Anorganice",
        "Cercetator In Tehnologia Substantelor Organice",
        "Inginer De Cercetare In Tehnologia Substantelor Organice",
        "Asistent De Cercetare In Tehnologia Substantelor Organice",
        "Cercetator In Petrochimie Si Carbochimie",
        "Inginer De Cercetare In Petrochimie Si Carbochimie",
        "Asistent De Cercetare In Petrochimie Si Carbochimie",
        "Cercetator In Tehnologia Compusilor Macromoleculari",
        "Inginer De Cercetare In Tehnologia Compusilor Macromoleculari",
        "Asistent De Cercetare In Tehnologia Compusilor Macromoleculari",
        "Cercetator In Controlul Calitatii Produselor Alimentare",
        "Inginer De Cercetare In Controlul Calitatii Produseloralimentare",
        "Asistent De Cercetare In Controlul Calitatii Produselor Alimentare",
        "Inginer Metalurgie Extractiva",
        "Inginer Minier",
        "Subinginer Metalurgist",
        "Subinginer Minier",
        "Inginer Preparator Minier",
        "Consilier Inginer Metalurg",
        "Inspector De Specialitate Inginer Metalurg",
        "Referent De Specialitate Inginer Metalurg",
        "Consilier Inginer Minier",
        "Expert Inginer Minier",
        "Inspector De Specialitate Inginer Minier",
        "Referent De Specialitate Inginer Minier",
        "Inginer Prelucrari Metalurgice",
        "Inginer Metalurgie Neferoasa",
        "Inginer Petrolist",
        "Subinginer Petrolist",
        "Consilier Inginer Petrolist",
        "Expert Inginer Petrolist",
        "Referent Inginer Petrolist",
        "Proiectant Inginer Petrolist",
        "Inginer Tehnolog Metalurg",
        "Proiectant Inginer Metalurg",
        "Proiectant Inginer In Minerit",
        "Inginer Mineralurg",
        "Cercetator In Exploatari Miniere",
        "Inginer De Cercetare In Exploatari Miniere",
        "Asistent De Cercetare In Exploatari Miniere",
        "Cercetator In Prepararea Substantelor Minerale Utile",
        "Inginer De Cercetare In Prepararea Substantelor Minerale Utile",
        "Asistent De Cercetare In Prepararea Substantelor Minerale Utile",
        "Cercetator In Petrol (Extractie-Prospectiune)",
        "Inginer De Cercetare In Petrol (Extractie-Prospectiune)",
        "Asistent De Cercetare In Petrol (Extractieprospectiune)",
        "Cercetator In Topografie Miniera",
        "Inginer De Cercetare In Topografie Miniera",
        "Asistent De Cercetare In Topografie Miniera",
        "Cercetator In Ingineria Proceselor Siderurgice",
        "Inginer De Cercetare In Ingineria Proceselor Siderurgice",
        "Asistent De Cercetare In Ingineria Proceselor Siderurgice",
        "Cercetator In Metalurgia Neferoasa",
        "Inginer De Cercetare In Metalurgia Neferoasa",
        "Asistent De Cercetare In Metalurgia Neferoasa",
        "Inginer De Cercetare In Turnarea Metalelor",
        "Asistent De Cercetare In Turnarea Metalelor",
        "Cercetator In Prelucrari Plastice Si Tratamente Termice",
        "Inginer De Cercetare In Prelucrari Plastice Si Tratamente Termice",
        "Asistent De Cercetare In Prelucrari Plastice Si Tratamente Termice",
        "Cercetator In Stiinta Materialelor",
        "Inginer De Cercetare In Stiinta Materialelor",
        "Asistent De Cercetare In Stiinta Materialelor",
        "Cercetator In Tehnologii Carbochimice",
        "Inginer De Cercetare In Tehnologii Carbochimice",
        "Asistent De Cercetare In Tehnologii Carbochimice",
        "Inginer De Cercetare In Instalatii Si Utilaje Pentru Transportul Si Depozitarea Produselor Petroliere",
        "Asistent De Cercetare In Instalatii Si Utilaje Pentru Transportul Si Depozitarea Produselor Petroliere",
        "Expert Inginer Metalurg",
        "Inginer Prelucrarea Sticlei Si Ceramicii",
        "Subinginer Prelucrarea Sticlei Si Ceramicii",
        "Inginer Materiale De Constructii",
        "Subinginer Materiale De Constructii",
        "Consilier Inginer Prelucrarea Sticlei Si Ceramicii",
        "Expert Inginer Prelucrarea Sticlei Si Ceramicii",
        "Inspector De Specialitate Inginer Prelucrarea Sticlei Si Ceramicii",
        "Referent De Specialitate Inginer Prelucrarea Sticlei Si Ceramicii",
        "Proiectant Inginer Ceramica, Sticla",
        "Chimist In Materiale Oxidice (Sticla, Ceramica)",
        "Subinginer Tehnologia Celulozei Si Hartiei",
        "Proiectant Inginer Celuloza Si Hartie",
        "Consilier Inginer Tehnologia Celulozei Si Hartiei",
        "Expert Inginer Tehnologia Celulozei Si Hartiei",
        "Inspector De Specialitate Inginer Tehnologia Celulozei Si Hartiei",
        "Referent De Specialitate Inginer Tehnologia Celulozei Si Hartiei",
        "Cercetator In Informatica",
        "Asistent De Cercetare In Informatica",
        "Cercetator In Filatura-Tesatorie",
        "Inginer De Cercetare In Filatura-Tesatorie",
        "Asistent De Cercetare In Filatura-Tesatorie",
        "Cercetator In Tricotaje-Confectii Textile",
        "Inginer De Cercetare In Tricotaje-Confectii Textile",
        "Asistent De Cercetare In Tricotaje-Confectii Textile",
        "Cercetator In Tehnologia Chimica A Produselor Textile, Pieii, Blanurilor Si Inlocuitorilor",
        "Inginer De Cercetare In Tehnologia Chimica A Produselor Textile, Pieii, Blanurilor Si Inlocuitorilor",
        "Asistent De Cercetare In Tehnologia Chimica A Produselor Textile, Pieii, Blanurilor Si Inlocuitorilor",
        "Cercetator In Confectii Din Piele Si Inlocuitori",
        "Inginer De Cercetare In Confectii Din Piele Si Inlocuitori",
        "Asistent De Cercetare In Confectii Din Piele Si Inlocuitori",
        "Cercetator In Exploatari Forestiere",
        "Inginer De Cercetare In Exploatari Forestiere",
        "Asistent De Cercetare In Exploatari Forestiere",
        "Inginer De Cercetare In Proiectarea Mobilei Si Produselor Finite Din Lemn",
        "Cercetator In Prelucrarea Lemnului",
        "Inginer De Cercetare In Prelucrarea Lemnului",
        "Asistent De Cercetare In Prelucrarea Lemnului",
        "Cercetator In Tehnologie Si Echipamente Neconventionale",
        "Inginer De Cercetare In Tehnologie Si Echipamente Neconventionale",
        "Asistent De Cercetare In Tehnologie Si Echipamente Neconventionale",
        "Cercetator In Tehnologia Celulozei, Hartiei, Poligrafiei Si Fibrelor",
        "Inginer De Cercetare In Tehnologia Celulozei, Hartiei, Poligrafiei Si Fibrelor",
        "Asistent De Cercetare In Tehnologia Celulozei, Hartiei, Poligrafiei Si Fibrelor",
        "Cercetator In Turnarea Metalelor",
        "Administrator Societate Comerciala",
        "Expert Achizitii Publice",
        "Expert Elaborare Documentatii Tehnice De Montaj",
        "Expert Monitorizare Si Control Lucrari De Montaj",
        "Expert Prevenire-Reducere Riscuri Tehnologice",
        "Expert Urmarire Comportare In Exploatare Lucrari Montaj",
        "Dispecer Energetic Feroviar",
        "Dispecer Centrala, Hidrocentru, Cascada, Dispecerate Teritoriale",
        "Dispecer Retea Distributie",
        "Dispecer Retele De Inalta Tensiune",
        "Inginer Electroenergetica",
        "Radiochimist",
        "Subinginer Electroenergetica",
        "Inginer Energetica Industriala",
        "Inginer Termoenergetica",
        "Proiectant Inginer Electrotehnic",
        "Proiectant Inginer Energetician",
        "Inginer Retele Electrice",
        "Subinginer Retele Electrice",
        "Inginer Hidroenergetica",
        "Inginer Centrale Nuclearoelectrice",
        "Subinginer Centrale Termoelectrice",
        "Inginer Exploatare Instalatii Nucleare",
        "Proiectant Subinginer Electrotehnic",
        "Proiectant Sisteme De Securitate",
        "Sef Tura Dispecer Energetic",
        "Cercetator In Electrotehnica",
        "Inginer De Cercetare In Electrotehnica",
        "Asistent De Cercetare In Electrotehnica",
        "Cercetator In Electrofizica",
        "Inginer De Cercetare In Electrofizica",
        "Asistent De Cercetare In Electrofizica",
        "Cercetator In Metrologie",
        "Inginer De Cercetare In Metrologie",
        "Asistent De Cercetare In Metrologie",
        "Cercetator In Electromecanica",
        "Inginer De Cercetare In Electromecanica",
        "Asistent De Cercetare In Electromecanica",
        "Cercetator Roboti Industriali",
        "Inginer De Cercetare Roboti Industriali",
        "Asistent De Cercetare Roboti Industriali",
        "Cercetator In Centrale Termoelectrice",
        "Inginer De Cercetare In Centrale Termoelectrice",
        "Asistent De Cercetare In Centrale Termoelectrice",
        "Cercetator In Centrale Nuclearoelectrice",
        "Inginer De Cercetare In Centrale Nuclearoelectrice",
        "Asistent De Cercetare In Centrale Nuclearoelectrice",
        "Cercetator In Electroenergetica",
        "Inginer De Cercetare In Electroenergetica",
        "Asistent De Cercetare In Electroenergetica",
        "Cercetator In Energetica Industriala",
        "Inginer De Cercetare In Energetica Industriala",
        "Asistent De Cercetare In Energetica Industriala",
        "Inginer Electromecanic Scb",
        "Inginer Automatist",
        "Inginer Navigatie",
        "Inginer Electronist Transporturi, Telecomunicatii",
        "Inginer Productie",
        "Instructor Instalatii",
        "Instructor Linii",
        "Revizor Siguranta Circulatiei Feroviare",
        "Subinginer Automatist",
        "Subinginer Electronist Transporturi, Telecomunicatii",
        "Subinginer Reglaje Subansamble",
        "Inginer De Receptie Si Control Aeronave",
        "Proiectant Inginer Electronist",
        "Proiectant Inginer De Sisteme Si Calculatoare",
        "Proiectant Inginer Electromecanic",
        "Inginer Electromecanic",
        "Subinginer Electromecanic",
        "Capitan Secund",
        "Capitan Port (Studii Superioare)",
        "Specialist Mentenanta Electromecanica-Automatica Echipamente Industriale",
        "Inspector Aeronautic",
        "Inginer Sisteme De Securitate",
        "Cercetator In Electronica Aplicata",
        "Inginer De Cercetare In Electronica Aplicata",
        "Asistent De Cercetare In Electronica Aplicata",
        "Cercetator In Comunicatii",
        "Inginer De Cercetare In Comunicatii",
        "Asistent De Cercetare In Comunicatii",
        "Cercetator In Microelectronica",
        "Inginer De Cercetare In Microelectronica",
        "Asistent De Cercetare In Microelectronica",
        "Cercetator In Telecomenzi Si Electronica In Transporturi",
        "Inginer De Cercetare In Telecomenzi Si Electronica In Transporturi",
        "Asistent De Cercetare In Telecomenzi Si Electronica In Transporturi",
        "Cercetator In Calculatoare",
        "Inginer De Cercetare In Calculatoare",
        "Asistent De Cercetare In Calculatoare",
        "Cercetator In Automatica",
        "Inginer De Cercetare In Automatica",
        "Asistent De Cercetare In Automatica",
        "Inginer Emisie",
        "Inginer Montaj",
        "Inginer Electrotehnist",
        "Inginer Imagine",
        "Inginer Sunet",
        "Inginer-Sef Car Reportaj",
        "Subinginer-Sef Car Reportaj",
        "Inginer-Sef Schimb Emisie",
        "Subinginer Iluminat Tehnologic",
        "Inginer Proiectant Comunicatii",
        "Subinginer Proiectant Comunicatii",
        "Inginer/Inspector De Specialitate/Referent De Specialitate/Expert In Serviciile De Trafic Aerian",
        "Consilier Tehnic",
        "Inginer Iluminare",
        "Sef Studio Rtv",
        "Arhitect Cladiri",
        "Conductor Arhitect",
        "Arhitect Restaurari",
        "Consilier Arhitect",
        "Expert Arhitect",
        "Inspector De Specialitate Arhitect",
        "Referent De Specialitate Arhitect",
        "Proiectant Arhitect",
        "Cercetator In Arhitectura",
        "Asistent De Cercetare In Arhitectura",
        "Arhitect Peisagistica Si Amenajarea Teritoriului",
        "Designer Industrial",
        "Grafician Industrial",
        "Lucrator In Ateliere De Modele",
        "Costumier",
        "Pictor Creator Costume",
        "Modelier Confectii",
        "Designer Vestimentar",
        "Cercetator In Arte Plastice ",
        "Asistent De Cercetare In Arte Plastice ",
        "Cercetator In Arte Plastice ",
        "Asistent De Cercetare In Arte Plastice-Textile (Tapiserie, Contexturi, Moda,Imprimeuri)",
        "Cercetator In Arte Plastice ",
        "Asistent De Cercetare In Arte Plastice ",
        "Urbanist",
        "Arhitect Urbanism",
        "Cartograf",
        "Inginer Geodez",
        "Subinginer Geodez",
        "Inginer Topograf",
        "Inginer Topograf Minier",
        "Proiectant Inginer Geodez",
        "Designer Grafica (Studii Medii)",
        "Animator Film De Animatie (Studii Medii)",
        "Intermediarist Film Desene Animate (Studii Medii)",
        "Stilizator Film Desene Animate (Studii Medii)",
        "Asistent Regizor Studio",
        "Asistent Regizor Emisie",
        "Designer Floral",
        "Videojurnalist",
        "Art Director",
        "Designer Pagini Web (Studii Superioare)",
        "Designer Grafica (Studii Superioare)",
        "Grafician Calculator (Studii Medii)",
        "Designer Pagini Web (Studii Medii)",
        "Medic Medicina Generala",
        "Medic Rezident",
        "Consilier Medic",
        "Expert Medic",
        "Inspector De Specialitate Medic",
        "Referent De Specialitate Medic",
        "Medic Primar",
        "Medic Medicina In Familie",
        "Cercetator In Medicina Generala",
        "Asistent De Cercetare In Medicina Generala",
        "Medic Specialist",
        "Asistent Medical Generalist",
        "Moasa",
        "Cercetator In Medicina Traditionala",
        "Asistent De Cercetare In Medicina Traditionala",
        "Instructor Ergoterapie",
        "Tehnician Homeopat",
        "Instructor De Educatie Sanitara",
        "Bioenergetician",
        "Infoenergetician Radiestezist",
        "Terapeut In Terapii Complementare",
        "Paramedic",
        "Epizotolog",
        "Medic Veterinar",
        "Medic Veterinar ",
        "Cercetator In Medicina Veterinara",
        "Asistent De Cercetare In Medicina Veterinara",
        "Medic Stomatolog",
        "Medic Stomatolog Rezident",
        "Medic Stomatolog De Specialitate",
        "Cercetator In Medicina Stomatologica",
        "Asistent De Cercetare In Medicina Stomatologica",
        "Farmacist",
        "Farmacist Rezident",
        "Farmacist De Specialitate",
        "Inginer Clinic",
        "Specialist In Domeniul Securitatii Si Sanatatii In Munca",
        "Coordonator In Materie De Securitate Si Sanatate In Munca (Studii Superioare)",
        "Cercetator Stiintific In Bacteriologie, Microbiochimie, Farmacologie",
        "Asistent De Cercetare In Bacteriologie, Microbiologie, Biochimie, Farmacologie",
        "Igienist",
        "Evaluator De Risc Si Auditor In Domeniul Securitatii Sisanatatii In Munca",
        "Fiziokinetoterapeut",
        "Fizioterapeut",
        "Cercetator In Fiziokinetoterapie",
        "Asistent De Cercetare In Fiziokinetoterapie",
        "Kinetoterapeut",
        "Profesor De Cultura Fizica Medicala",
        "Asistent De Nutritie",
        "Dietetician",
        "Nutritionist Si Dietetician",
        "Instructor Logoped",
        "Interpret In Limbaj Mimico-Gestual (Studii Medii)",
        "Logoped",
        "Audiolog",
        "Optometrist (Studii Superioare)",
        "Medic Igienist",
        "Medic Expertiza A Capacitatii De Munca",
        "Medic Legist",
        "Bioinginer Medical",
        "Asistent Medical (Studii Superioare)",
        "Fizician Medical",
        "Medic Specialist Psihiatru",
        "Medic De Familie Cu Competente In Sanatatea Mintala",
        "Cercetator In Educatie Fizica Si Sport",
        "Asistent De Cercetare In Educatie Fizica Si Sport",
        "Asistent Universitar",
        "Conferentiar Universitar",
        "Lector Universitar",
        "Preparator Invatamantul Universitar",
        "Profesor Universitar",
        "Expert Centre De Perfectionare",
        "Profesor In Invatamantul Profesional Si De Maistri",
        "Profesor In Invatamantul Liceal, Postliceal",
        "Profesor In Invatamantul Gimnazial",
        "Profesor In Invatamantul Primar",
        "Invatator",
        "Institutor",
        "Profesor In Invatamantul Prescolar",
        "Educatoare",
        "Educator Puericultor",
        "Cercetator In Pedagogie",
        "Asistent De Cercetare In Pedagogie",
        "Consilier Invatamant",
        "Expert Invatamant",
        "Inspector Scolar",
        "Referent De Specialitate Invatamant",
        "Defectolog",
        "Interpret In Limbaj Mimico-Gestual (Studii Superioare)",
        "Educator In Unitati De Handicapati",
        "Instructor-Educator In Unitati De Handicapati",
        "Pedagog De Recuperare",
        "Secretar Institut, Facultate",
        "Mentor",
        "Consilier Scolar",
        "Designer Instructional",
        "Dezvoltator De E-Learning",
        "Laborant In Invatamant",
        "Maistru Instructor",
        "Pedagog Scolar",
        "Secretar Scoala",
        "Sef Atelier Scoala",
        "Mediator Scolar",
        "Inspector Scolar Pentru Implementarea Descentralizarii Institutionale",
        "Inspector Scolar Pentru Managementul Resurselor Umane",
        "Inspector Scolar Pentru Mentorat",
        "Inspector Scolar Pentru Dezvoltarea Resursei Umane",
        "Inspector Scolar Pentru Educatie Permanenta",
        "Inspector Scolar Pentru Invatamant Particular Si Lternative Educationale",
        "Inspector Scolar Pentru Invatamantul Special",
        "Director Centrul Judetean De Asistenta Si Resurse Educationale (Cjare)",
        "Consilier Pentru Tineret",
        "Controlor Tezaur",
        "Expert Contabil-Verificator",
        "Revizor Contabil",
        "Referent De Specialitate Financiar-Contabilitate",
        "Auditor Intern",
        "Controlor De Gestiune",
        "Auditor Financiar",
        "Cenzor",
        "Comisar Garda Financiara",
        "Consilier Financiar-Bancar",
        "Expert Financiar-Bancar",
        "Inspector Financiar-Bancar",
        "Inspector Asigurari",
        "Comisar Principal",
        "Consultant Bugetar",
        "Dealer",
        "Evaluator",
        "Analist Investitii",
        "Manager De Fond Actiuni/Obligatiuni",
        "Consultant Plasamente Valori Mobiliare",
        "Agent Capital De Risc",
        "Administrator Credite",
        "Specialist Control Risc",
        "Specialist Evaluare Daune",
        "Lichidator",
        "Administrator Judiciar",
        "Analist Pret De Revenire/Costuri",
        "Expert Fiscal",
        "Consultant Fiscal",
        "Inspector General De Banca",
        "Economist Banca",
        "Manager Banca",
        "Manager De Operatiuni/Produs",
        "Manager Relatii Cu Clientii Bancii/Societate De Leasing",
        "Trezorier (Studii Superioare)",
        "Analist Bancar/Societate De Leasing",
        "Ofiter Bancar (Credite, Marketing, Produse Si Servicii Bancare)",
        "Administrator Bancar/Produs Leasing",
        "Operator Cifru (Mesaje Cifrate)",
        "Proiectant Produse Bancare",
        "Consultant Bancar",
        "Agent Compensare (Interbancara)",
        "Referent Bancar/Societate De Leasing",
        "Ofiter Conformitate",
        "Expert Conformitate",
        "Ofiter Securitatea Informatiei (Security Officer ",
        "Administrator De Risc",
        "Analist Credite",
        "Inspector De Specialitate Asigurari",
        "Inspector De Specialitate Subscriere",
        "Referent De Specialitate Asigurari",
        "Consilier Vanzari Asigurari",
        "Inspector Coordonator Asigurari",
        "Inspector De Risc",
        "Inspector De Specialitate Daune",
        "Inspector Coordonator Daune",
        "Specialist Sistem Asigurari",
        "Expert Evaluator De Intreprinderi",
        "Expert Evaluator De Proprietati Imobiliare",
        "Expert Evaluator De Bunuri Mobile",
        "Expert Evaluator De Active Financiare",
        "Planificator/Specialist Plan Sinteze",
        "Expert In Ingineria Costurilor Investitionale",
        "Expert Contractare Activitati Investitionale",
        "Expert Receptie Investitii Industriale",
        "Expert Eficientizare Investitii",
        "Expert Evaluare-Actualizare Devize Generale Investitii",
        "Expert Elaborare-Evaluare Documentatii Achizitii Investitionale",
        "Expert In Management Activitati Investitionale",
        "Evaluator Proiecte",
        "Inspector Casier",
        "Broker De Tehnologii",
        "Cercetator In Finante-Banci",
        "Asistent De Cercetare In Finante-Banci",
        "Cercetator In Gestiune, Contabilitate, Control Financiar",
        "Asistent De Cercetare In Gestiune, Contabilitate, Control Financiar",
        "Analist Financiar",
        "Auditor Intern In Sectorul Public",
        "Asistent Analist",
        "Specialist Bancar",
        "Analist Financiar Bancar",
        "Asistent Bancar",
        "Specialist/Analist Organizare",
        "Manager Proiect",
        "Specialist Imbunatatire Procese",
        "Specialist Strategie Industriala",
        "Responsabil Proces",
        "Coordonator Secretariat Studiouri Teritoriale",
        "Manager De Inovare",
        "Expert In Conducerea Si Organizarea Activitatilor De Mentenanta",
        "Manager Imbunatatire Procese",
        "Specialist Plan Progres",
        "Specialist In Planificarea, Controlul Si Raportarea Performantei Economice",
        "Consilier Administratia Publica",
        "Expert Administratia Publica",
        "Inspector De Specialitate In Administratia Publica",
        "Referent De Specialitate In Administratia Publica",
        "Consultant In Administratia Publica",
        "Reglementator",
        "Agent De Dezvoltare",
        "Administrator Public",
        "Inspector De Integritate",
        "Examinator De Stat De Specialitate",
        "Administrator Publicatii",
        "Agent Consular",
        "Expert Accesare Fonduri Structurale Si De Coeziune Europene",
        "Consilier Afaceri Europene",
        "Referent Relatii Externe",
        "Inspector De Trafic A.R.R. (Studii Superioare)",
        "Expert Informatii Pentru Afaceri",
        "Administrator Editura",
        "Expert Aplicare Legislatie Armonizata In Domeniul Industriei Si Comertului",
        "Expert Legislatia Muncii",
        "Consilier Forta De Munca Si Somaj",
        "Expert Forta De Munca Si Somaj",
        "Inspector De Specialitate Forta De Munca Si Somaj",
        "Expert In Securitate Si Sanatate In Munca",
        "Referent De Specialitate Forta De Munca Si Somaj",
        "Consilier Orientare Privind Cariera",
        "Consultant In Domeniul Fortei De Munca",
        "Analist Piata Muncii",
        "Analist Recrutare/Integrare Salariati",
        "Analist Sisteme Salarizare",
        "Consultant Reconversie-Mobilitate Personal",
        "Consultant Conditii De Munca",
        "Specialist Sisteme De Calificare",
        "Specialist Resurse Umane",
        "Consilier Vocational",
        "Consultant In Standardizare",
        "Consultant In Resurse Umane",
        "Consultant Intern In Resurse Umane",
        "Specialist In Formare",
        "Specialist In Recrutare",
        "Specialist In Compensatii Si Beneficii",
        "Specialist In Dezvoltare Organizationala",
        "Specialist In Relatii De Munca",
        "Formator",
        "Formator De Formatori",
        "Organizator/Conceptor/Consultant Formare",
        "Inspector De Specialitate Formare, Evaluare Si Selectie Profesionala",
        "Evaluator De Competente Profesionale",
        "Manager De Formare",
        "Administrator De Formare",
        "Art Director Publicitate (Studii Medii)",
        "Organizator Activitate Turism (Studii Superioare)",
        "Specialist Marketing",
        "Manager De Produs",
        "Specialist In Relatii Publice",
        "Mediator",
        "Referent De Specialitate Marketing",
        "Specialist Protocol Si Ceremonial",
        "Consultant Cameral",
        "Purtator De Cuvant",
        "Brand Manager",
        "Organizator Protocol",
        "Organizator Relatii",
        "Organizator Targuri Si Expozitii",
        "Prezentator Expozitii",
        "Specialist Relatii Sociale",
        "Expert Relatii Externe",
        "Curier Diplomatic",
        "Specialist Garantii Auto",
        "Analist Servicii Client",
        "Asistent Director/Responsabil De Functiune (Studii Superioare)",
        "Corespondent Comercial",
        "Asistent Comercial",
        "Specialist In Activitatea De Lobby",
        "Analist Cumparari/Consultant Furnizori",
        "Reprezentant Medical",
        "Proiectant Sisteme Informatice",
        "Analist",
        "Programator",
        "Inginer De Sistem In Informatica",
        "Programator De Sistem Informatic",
        "Inginer De Sistem Software",
        "Manager Proiect Informatic",
        "Specialist In Domeniul Proiectarii Asistate Pe Calculator",
        "Specialist In Proceduri Si Instrumente De Securitate A Istemelor Informatice",
        "Consultant In Informatica",
        "Administrator Baze De Date",
        "Administrator Sistem De Securitate Bancara",
        "Administrator De Retea De Calculatoare",
        "Administrator De Retea De Telefonie Voip",
        "Avocat",
        "Jurisconsult",
        "Consilier Juridic",
        "Procuror",
        "Judecator",
        "Magistrat-Asistent",
        "Judecator Inspector",
        "Magistrat Consultant",
        "Consilier De Probatiune",
        "Inspector Probatiune",
        "Executor Judecatoresc",
        "Inspector Justitie",
        "Expert Jurist",
        "Consilier De Justitie",
        "Referent De Specialitate In Justitie",
        "Notar",
        "Inspector General Judecatoresc",
        "Inspector General Notarial",
        "Inspector General Penitenciare",
        "Consilier Armonizare Legislativa",
        "Expert Armonizare Legislativa",
        "Analist Armonizare Legislativa",
        "Registrator Carte Funciara",
        "Revizor Jurist",
        "Cercetator In Domeniul Stiintelor Juridice",
        "Asistent De Cercetare In Domeniul Stiintelor Juridice",
        "Executor Bancar",
        "Consilier Proprietate Industriala Autorizat",
        "Specialist Proprietate Intelectuala",
        "Expert Prevenire Si Combatere A Coruptiei",
        "Arhivist",
        "Conservator Opere De Arta Si Monumente Istorice (Studii Superioare)",
        "Muzeograf",
        "Restaurator Opere De Arta Si Monumente Istorice (Studii Superioare)",
        "Conservator Arhiva (Studii Superioare)",
        "Restaurator Arhiva (Studii Superioare)",
        "Restaurator Bunuri Culturale (Studii Superioare)",
        "Bibliograf",
        "Bibliotecar (Studii Superioare)",
        "Documentarist (Studii Superioare)",
        "Referent Difuzare Carte",
        "Lector Carte",
        "Bibliotecar Arhivist",
        "Referent De Specialitate Asezamant Cultural",
        "Consilier/Expert/Inspector/Referent/Economist In Management",
        "Consilier/Expert/Inspector/Referent/Economist In Economie Generala",
        "Consilier/Expert/Inspector/Referent/Economist In Economia Mediului",
        "Consilier/Expert/Inspector/Referent/Economist In Comert Si Marketing",
        "Consilier/Expert/Inspector/Referent/Economist In Relatii Economice Internationale",
        "Consilier/Expert/Inspector/Referent/Economist In Gestiunea Economica",
        "Consultant In Management",
        "Tehnician Economist",
        "Inginer Economist",
        "Inspector De Concurenta",
        "Administrator Financiar (Patrimoniu) (Studii Superioare)",
        "Cercetator Economist In Management",
        "Asistent De Cercetare Economist In Management",
        "Cercetator Economist In Economia Mediului",
        "Asistent De Cercetare Economist In Economia Mediului",
        "Cercetator Economist In Economia Generala",
        "Asistent De Cercetare Economist In Economia Generala",
        "Cercetator Economist In Economie Agroalimentara",
        "Asistent De Cercetare Economist In Economie Agroalimentara",
        "Cercetator Economist In Marketing",
        "Asistent De Cercetare Economist In Marketing",
        "Cercetator Economist In Relatii Economice Internationale",
        "Asistent De Cercetare Economist In Relatii Economice Internationale",
        "Cercetator Economist In Gestiunea Economica",
        "Asistent De Cercetare Economist In Gestiuneaeconomica",
        "Secretar Economic (Studii Superioare)",
        "Sociolog",
        "Geograf",
        "Analist De Mediu",
        "Analist In Turism",
        "Analist Teritorial",
        "Arheolog",
        "Cercetator De Dezvoltare Comunitara",
        "Cercetator In Sociologie",
        "Asistent De Cercetare In Sociologie",
        "Cercetator In Antropologie",
        "Asistent De Cercetare In Antropologie",
        "Cercetator In Geografie",
        "Asistent De Cercetare In Geografie",
        "Cercetator In Arheologie",
        "Asistent De Cercetare In Arheologie",
        "Cercetator In Etnologie",
        "Asistent De Cercetare In Etnologie",
        "Filozof",
        "Istoric",
        "Istoriograf",
        "Politolog",
        "Cercetator In Filozofie",
        "Asistent De Cercetare In Filozofie",
        "Cercetator In Istorie",
        "Asistent De Cercetare In Istorie",
        "Cercetator In Stiintele Politice",
        "Asistent De Cercetare In Stiintele Politice",
        "Psiholog In Specialitatea Psihologie Clinica",
        "Psiholog In Specialitatea Consiliere Psihologica",
        "Psiholog In Specialitatea Psihoterapie",
        "Psiholog In Specialitatea Psihologia Muncii Si Organizationala",
        "Psiholog In Specialitatea Psihologia Transporturilor",
        "Psiholog In Specialitatea Psihologia Aplicata In Servicii",
        "Psiholog In Specialitatea Psihologie Educationala, Consiliere Scolara Si Vocationala",
        "Psiholog In Specialitatea Psihopedagogie Speciala",
        "Psiholog In Specialitatea Psihologie Aplicata In Domeniul Securitatii Nationale",
        "Psiholog In Specialitatea Psihologie Judiciara ",
        "Psiholog",
        "Psihopedagog",
        "Expert Poligraf",
        "Psiholog Scolar",
        "Cercetator In Psihologie",
        "Asistent De Cercetare In Psihologie",
        "Cercetator In Psihopedagogie Speciala",
        "Asistent De Cercetare In Psihopedagogie Speciala",
        "Terapeut Ocupational",
        "Asistent Social Nivel Superior",
        "Consilier In Domeniul Adictiilor",
        "Ofiter Control Doping",
        "Art-Terapeut",
        "Asistent Social Cu Competenta In Sanatatea Mintala",
        "Specialist In Evaluarea Vocationala A Persoanelor Cu Dizabilitati",
        "Specialist In Angajare Asistata",
        "Instructor-Educator Pentru Activitati De Resocializare",
        "Asistent Pentru Ingrijirea Persoanelor Varstnice",
        "Cercetator In Asistenta Sociala",
        "Asistent De Cercetare In Asistenta Sociala",
        "Arhiepiscop",
        "Arhiereu-Vicar",
        "Arhondar",
        "Cantor",
        "Capelan",
        "Cardinal",
        "Chevrasames",
        "Cantaret Bisericesc",
        "Consilier Culte",
        "Conducator Arhiepiscopal",
        "Diacon",
        "Episcop",
        "Exarh",
        "Haham",
        "Harmonist",
        "Hatip",
        "Imam",
        "Inspector Culte",
        "Majghian",
        "Melamed",
        "Mitropolit",
        "Muezin",
        "Muftiu",
        "Organist",
        "Pastor",
        "Patriarh",
        "Preot",
        "Presedinte Culte",
        "Protopop",
        "Provicar",
        "Rabin",
        "Secretar Culte",
        "Staret ",
        "Treibar",
        "Vestitor",
        "Vicar",
        "Poet",
        "Scriitor",
        "Comentator Publicist",
        "Corector (Studii Superioare)",
        "Corespondent Special (Tara Si Strainatate)",
        "Corespondent Radio",
        "Corespondent Presa",
        "Critic De Arta",
        "Editorialist",
        "Fotoreporter",
        "Lector Presa/Editura",
        "Publicist Comentator",
        "Redactor",
        "Reporter (Studii Superioare)",
        "Reporter Operator",
        "Secretar De Emisie (Studii Superioare)",
        "Secretar De Redactie (Studii Superioare)",
        "Secretar Responsabil De Agentie",
        "Sef Agentie Publicitate",
        "Tehnoredactor",
        "Ziarist",
        "Critic Literar",
        "Critic Muzical",
        "Comentator Radio Tv",
        "Redactor Rubrica",
        "Filolog",
        "Interpret",
        "Interpret Relatii Diplomatice",
        "Referent Literar",
        "Secretar Literar",
        "Traducator (Studii Superioare)",
        "Translator",
        "Grafolog",
        "Revizor Lingvist",
        "Terminolog",
        "Translator Emisie",
        "Cercetator In Lingvistica",
        "Asistent De Cercetare In Lingvistica",
        "Cercetator In Filologie",
        "Asistent De Cercetare In Filologie",
        "Caricaturist (Studii Superioare)",
        "Artist Plastic",
        "Desenator Film Animatie",
        "Grafician",
        "Machetist",
        "Pictor",
        "Pictor Scenograf",
        "Sculptor",
        "Sculptor Papusi",
        "Restaurator Tablouri",
        "Acompaniator",
        "Artist Liric",
        "Concert Maestru",
        "Corepetitor",
        "Corist",
        "Dirijor",
        "Ilustrator Muzical (Studii Superioare)",
        "Maestru Studii Canto",
        "Instrumentist",
        "Maestru Cor",
        "Referent Muzical",
        "Secretar Muzical",
        "Sef Orchestra",
        "Solist Instrumentist",
        "Solist Vocal",
        "Sufleur Opera",
        "Copiator Note Muzicale",
        "Specialist Instrumente De Suflat",
        "Artist Instrumentist",
        "Solist Concertist",
        "Dirijor Cor",
        "Maestru Corepetitor",
        "Artist Liric Opera",
        "Corist Opera",
        "Maestru Acordor Pian Clavecin",
        "Maestru Lutier",
        "Specialist Orga",
        "Regizor Muzical",
        "Cantaret",
        "Instrumentist Muzicant",
        "Disc-Jockey",
        "Video-Jockey",
        "Maestru De Ceremonii",
        "Instrumentist (Studii Medii)",
        "Balerin",
        "Coregraf",
        "Maestru Studii De Balet",
        "Maestru De Balet",
        "Solist Balet",
        "Maestru Dans",
        "Dansator",
        "Instructor De Dans",
        "Consultant Artistic",
        "Corector Transmisie",
        "Instructor Film",
        "Instructor Retea Cinematografica",
        "Lector Scenarii",
        "Intermediarist Film De Desene Animate (Studii Superioare)",
        "Stilizator Film De Desene Animate (Studii Superioare)",
        "Producator Delegat Film",
        "Realizator Emisiuni Rtv",
        "Regizor Artistic",
        "Regizor Emisie",
        "Regizor Studio",
        "Regizor Sunet",
        "Regizor Tehnic",
        "Secretar Sef Productie Film",
        "Sufleur Teatru",
        "Maestru Artist Circ",
        "Producator Rtv (Stiri)",
        "Editor Rtv (Stiri)",
        "Director Imagine",
        "Referent De Specialitate Selectie Programe Tv",
        "Copywriter Publicitate (Studii Superioare)",
        "Mediaplanner",
        "Producator Delegat Evenimente De Marketing",
        "Redactor Prezentator De Televiziune",
        "Animator Film De Animatie (Studii Superioare)",
        "Director Productie Film",
        "Coordonator Productie Film",
        "Asistent Productie Film",
        "Producator Audiovideo",
        "Editor Coordonator Programe Tv",
        "Director De Creatie",
        "Organizator Productie (Studii Superioare)",
        "Scenograf",
        "Asistent Scenograf",
        "Videojurnalist (Studii Superioare)",
        "Producator Delegat Pentru Teatru",
        "Regizor Culise",
        "Regizor Scena",
        "Secretar Platou",
        "Actor",
        "Actor Manuitor De Papusi",
        "Artist Circ",
        "Prezentator (Crainic) Radio",
        "Prezentator (Crainic) Televiziune",
        "Acrobat",
        "Clovn",
        "Magician",
        "Hipnotizator",
        "Trapezist",
        "Cascador",
        "Figurant",
        "Dresor",
        "Laborant Chimist",
        "Tehnician Chimist",
        "Laborant Determinari Fizico-Mecanice",
        "Tehnician Determinari Fizico-Mecanice",
        "Laborant Determinari Geologice Si Geotehnice",
        "Laborant Tehnica Nucleara",
        "Tehnician Meteorolog",
        "Tehnician Geolog",
        "Tehnician Hidrometru",
        "Prospector ",
        "Tehnician Hidrolog",
        "Tehnician Hidrogeolog",
        "Laborant Operator Centrale Termice",
        "Metrolog",
        "Tehnician Metrolog",
        "Asistent Fizica Si Chimie",
        "Operator Meteorolog",
        "Meteorolog Aeronautic Tehnician",
        "Operator Specialist Curatare Chimica La Schimbatoarele De Caldura Cu Placi",
        "Maistru Constructii Civile, Industriale Si Agricole",
        "Maistru Normator",
        "Tehnician Constructor",
        "Tehnician Hidroamelioratii",
        "Tehnician Hidrotehnic",
        "Tehnician Topometrist",
        "Tehnician Proiectant In Constructii",
        "Maistru Instalator In Constructii",
        "Tehnician Instalatii In Constructii",
        "Diriginte Santier",
        "Tehnician Laborant Pentru Lucrari De Drumuri Si Poduri",
        "Tehnician In Industria Materialelor De Constructii",
        "Maistru In Industria Materialelor De Constructii",
        "Tehnician Proiectant In Industria Materialelor De Constructii",
        "Tehnician Devize Si Masuratori In Constructii",
        "Tehnician Devizier",
        "Tehnician Atasamentist",
        "Dispecer Gestiune Uraniu",
        "Maistru Electromecanic",
        "Maistru Energetician/Electrician",
        "Tehnician Electroenergetician, Termoenergetician",
        "Tehnician Electromecanic",
        "Tehnician Energetician/Electrician",
        "Tehnician Proiectant Energetician/Electrician",
        "Maistru Electrician In Constructii",
        "Tehnician Mentenanta Electromecanica ",
        "Sef/Sef Adjunct Tura Statie Electrica (Studii Medii)",
        "Maistru Electronica",
        "Tehnician Electronica",
        "Tehnician Proiectant Electronica",
        "Maistru Cazangerie",
        "Maistru Instalatii Navale",
        "Maistru Intretinere Si Reparatii Masini-Unelte, Utilitati, Service, Prototipuri",
        "Maistru Lacatus, Constructii Metalice",
        "Maistru Lacatus Mecanic",
        "Tehnician Proiectant Mecanic",
        "Mecanic Pentru Intretinerea Aparatelor De Lansare La Zbor",
        "Maistru Mecanic",
        "Maistru Mecanic Auto",
        "Maistru Mecanica Agricola",
        "Maistru Mecanica Fina",
        "Maistru Montaj",
        "Maistru Prelucrari Mecanice",
        "Maistru Sculer-Matriter",
        "Maistru Sudura",
        "Tehnician Constructii Navale",
        "Tehnician Instalatii De Bord (Avion)",
        "Tehnician Masini Si Utilaje",
        "Tehnician Mecanic",
        "Tehnician Prelucrari Mecanice",
        "Tehnician Sudura",
        "Tehnician Tehnolog Mecanic",
        "Maistru Mecanic Masini Si Utilaje Pentru Constructii",
        "Tehnician Mentenanta Mecanica Echipamente Industriale",
        "Tehnician Incercari Componente Vehicule/Grup Motopropulsor/Optimizare Energetica/Sisteme De Masurare",
        "Tehnician Documentatie Studii",
        "Tehnician Prestatii Vehicule",
        "Tehnician Reglementari/Omologari Oficiale",
        "Tehnician/Tehnician Responsabil Afacere, Metode Implantare",
        "Tehnician/Tehnician Responsabil Afacere, Metode Gestiune Mijloace Si Utilaje",
        "Tehnician/Tehnician Responsabil Afacere, Metode Pregatire De Industrializare",
        "Tehnician/Tehnician Responsabil Afacere, Metode Logistica",
        "Tehnician/Tehnician Responsabil Afacere, Metode Organizarea Si Masurarea Muncii",
        "Maistru Fabricarea Armamentului",
        "Inspector Cu Supravegherea Si Verificarea Tehnica A Instalatiilor",
        "Inspector Iscir",
        "Decontaminator",
        "Laborant Apa Si Apa Grea",
        "Laborant Control Dozimetrie",
        "Laborant Petrolist/Industria Chimica",
        "Maistru Petrolist/Industria Chimica",
        "Laborant Apa Potabila",
        "Tehnician Petrolist Chimie Industriala",
        "Laborant Petrochimist",
        "Maistru La Fabricarea Munitiei",
        "Laborant Structura Macroscopica Si Microscopica",
        "Maistru Metalurgie",
        "Maistru Minier",
        "Maistru Presator Metale",
        "Maistru Termotehnist",
        "Tehnician Metalurgie",
        "Tehnician Minier",
        "Tehnician Proiectant Minier",
        "Tehnician Proiectant Metalurg",
        "Tehnician Mineralurg",
        "Maistru Mineralurg",
        "Maistru Termist-Tratamentist",
        "Probator Hidraulic Piese Turnate",
        "Desenator Tehnic",
        "Trasator",
        "Desenator",
        "Topograf",
        "Trasator Naval ",
        "Trasator Optic",
        "Tehnician Proiectant",
        "Maistru In Industria Celulozei Si Hartiei",
        "Maistru Tipograf",
        "Paginator Tipograf",
        "Tehnician Normare, Salarizare, Organizare",
        "Tehnician Pret De Cost",
        "Tehnician Programare, Lansare, Urmarirea Productiei",
        "Tehnician Pret De Revenire/Costuri",
        "Tehnician Gestiune Salariala",
        "Tehnician Gestiunea Productiei",
        "Tehnician Gestiune Stoc",
        "Maistru In Industriile Textila, Pielarie",
        "Tehnician In Industria Confectiilor Din Piele Si Inlocuitori",
        "Tehnician In Industria Confectiilor Si Tricotajelor",
        "Tehnician In Industria Incaltamintei",
        "Tehnician In Industria Pielariei",
        "Tehnician In Industria Textila",
        "Tehnician Proiectant Textile, Pielarie",
        "Laborant In Industriile Textila, Pielarie",
        "Sef Formatie Industria Confectiilor Imbracaminte",
        "Expert Tehnic Extrajudiciar",
        "Tehnician In Industria Sticlei Si Ceramicii",
        "Maistru In Industria Sticlei Si Ceramicii",
        "Maistru Frigotehnist",
        "Tehnician Frigotehnist",
        "Tehnician In Industria Alimentara",
        "Tehnician Laborant Analize Produse Alimentare",
        "Tehnician In Industria Alimentara Extractiva",
        "Tehnician In Industria Alimentara Fermentativa",
        "Tehnician In Industria Carnii, Laptelui Si Conservelor",
        "Tehnician In Morarit Si Panificatie",
        "Tehnician Proiectant In Industria Alimentara",
        "Maistru In Industria Alimentara",
        "Tehnolog Alimentatie Publica",
        "Operator Control Nedistructiv",
        "Operator Control Nedistructiv Cu Radiatii Penetrante",
        "Operator Control Nedistructiv Cu Ultrasunete",
        "Operator Control Nedistructiv Cu Lichide Penetrante",
        "Operator Control Nedistructiv Cu Particule Magnetice",
        "Operator Control Nedistructiv Cu Curenti Turbionari",
        "Operator Control Nedistructiv Pentru Verificarea Etanseitatii",
        "Operator Responsabil Cu Supravegherea Tehnica A Instalatiilor",
        "Masurator De Gaze, Temperatura Si Radiatii",
        "Controlor De Productie La Minele De Aur Nativ",
        "Salvator Minier",
        "Controlor Calitate Dupa Efectuarea Probelor La Armament Si Munitie",
        "Controlor Calitate Pentru Executia Elementelor La Armament Si Munitie",
        "Controlor De Calitate La Protejari Metalice",
        "Operator La Instalatiile Din Centrale Electrice",
        "Masinist La Instalatiile Din Centrale Electrice",
        "Operator La Instalatiile De Cazane Din Centrale Electrice",
        "Operator La Instalatiile De Turbine Cu Abur Sau Gaze",
        "Operator La Camera De Comanda Termica",
        "Masinist La Instalatiile Hidrotehnice Din Centraleelectrice",
        "Masinist La Instalatiile De Turbine Hidraulice",
        "Masinist La Centrale Diesel",
        "Operator Punct Termic",
        "Operator Centrala Termica",
        "Automatist Pentru Supraveghere Si Intretinere Cazane",
        "Operator Curatare Chimica La Schimbatoarele De Caldura Cu Placi",
        "Operator Surse Regenerabile De Energie",
        "Operator La Instalatii De Incinerare",
        "Operator Hidraulic In Alimentarile Cu Apa",
        "Operator Circuite Retea Apa",
        "Masinist La Conditionarea Aerului",
        "Operator La Tratarea Apei Tehnologice",
        "Operator Masini Refrigeratoare (Conservare Prin Frig)",
        "Operator Chimist La Chimizarea Metanului",
        "Rafinor",
        "Distilator La Prelucrarea Titeiului",
        "Operator Instalatii Imbuteliere Gaz Petrol Lichefiat",
        "Maistru-Operator La Roboti Industriali",
        "Tehnician-Operator La Roboti Industriali",
        "Tehnician In Industria Celulozei Si Hartiei",
        "Controlor De Conformitate In Industria De Masini",
        "Tehnician Asigurarea Calitatii",
        "Tehnician Analist Calitate",
        "Tehnician Cotator Calitate",
        "Tehnician In Bacteriologie",
        "Tehnician In Biochimie",
        "Tehnician In Hematologie",
        "Tehnician In Serologie",
        "Tehnician In Biologie",
        "Tehnician In Protectia Mediului (Tehnician Ecolog)",
        "Evaluator Si Auditor De Mediu",
        "Tehnician Agronom ",
        "Tehnician Zootehnist ",
        "Tehnician Pedolog",
        "Tehnician In Industrializarea Lemnului",
        "Tehnician Proiectant In Industrializarea Lemnului",
        "Maistru In Industrializarea Lemnului",
        "Tehnician Silvic ",
        "Tehnician In Reconstructia Ecologica",
        "Tehnician Cadastru Forestier",
        "Tehnician Amenajist",
        "Tehnician Proiectant In Reconstructie Ecologica",
        "Ofiter Ajutor Fluvial/Portuar",
        "Ofiter Rtg",
        "Ofiter Electrician Fluvial/Portuar",
        "Agent De Nava",
        "Ofiter Electrician Maritim",
        "Ofiter Mecanic Maritim",
        "Ajutor Ofiter Mecanic Fluvial",
        "Capitan Fluvial",
        "Capitan Port",
        "Ofiter Intendent",
        "Ofiter Port",
        "Ofiter De Punte Fluvial/Portuar",
        "Pilot De Dunare Maritima",
        "Sef Echipaj Maritim/Fluvial",
        "Pilot De Mare Larga, Pilot De Port Maritim",
        "Dragor Maritim/Fluvial",
        "Pilot De Port Maritim Aspirant/Pilot De Dunare Aspirant",
        "Ofiter De Punte Maritim",
        "Ofiter De Punte Maritim Aspirant/Ofiter Mecanic Maritim Aspirant/Ofiter Electrician Maritim Aspirant",
        "Comandant Detasament Zbor",
        "Comandant Insotitor De Bord",
        "Copilot",
        "Inspector Pilotaj",
        "Mecanic Navigant Aviatie",
        "Pilot Aeronave",
        "Pilot Comandant Avion",
        "Pilot Incercare",
        "Pilot Receptie Si Control Aeronave",
        "Parasutist Receptie Si Control",
        "Parasutist Incercator",
        "Pilot Parasutism Incercator",
        "Pilot Instructor Aeronave",
        "Instructor Parasutism",
        "Mecanic Navigant Instructor",
        "Maistru Aviatie",
        "Tehnician Aviatie",
        "Controlor Dirijare Nonradar",
        "Controlor Sol",
        "Controlor Trafic Aviatia Civila",
        "Dispecer Sol",
        "Navigator Dirijare Radar",
        "Navigator Aviatia Civila",
        "Navigator Dirijare Nonradar",
        "Navigator Dirijare Zbor",
        "Navigator Instructor Dirijare Radar Si Nonradar",
        "Navigator Sol",
        "Operator Radar",
        "Operator Radiotelecomunicatii Aeronautice",
        "Controlor Trafic Aerian Dirijare Nonradar",
        "Controlor Trafic Aerian Dirijare Radar",
        "Controlor Trafic Aerian Informare",
        "Navigator Informare",
        "Operator/Specialist/Instructor Telecomunicatii Aeronauticeaviatie Civila",
        "Sef Tura Telecomunicatii Aeronautice Aviatie Civila",
        "Controlor Trafic Aerian (Simulator Trafic Aerian)",
        "Navigator Instructor Informare",
        "Agent Salvare Aeroportuara Si Instalatii De Stinsincendii",
        "Masinist Agregate Aerodrom",
        "Operator Instalatii Control Antiterorist/Antideturnare",
        "Operator Radionavigant Aviatie",
        "Operator Radionavigant Instructor Aviatie",
        "Tehnician Securitate Aeriana",
        "Operator De Handling",
        "Inspector Siguranta Operationala",
        "Agent De Securitate Aeroportuara",
        "Dispecer Operatiuni De Zbor",
        "Referent/Inspector In Serviciile De Trafic Aerian",
        "Operator Dispecerat Operational De Supraveghere In Serviciile De Trafic Aerian",
        "Tehnician Protectia Navigatiei Aeriene (Comunicatii, Navigatie, Supraveghere)",
        "Maistru Protectia Navigatiei Aeriene (Comunicatii, Navigatie, Supraveghere)",
        "Sef Tura Protectia Navigatiei Aeriene (Comunicatii, Navigatie, Supraveghere)",
        "Tehnician In Serviciile De Trafic Aerian",
        "Maistru Aparate Electromedicale",
        "Tehnician Aparate Electromedicale",
        "Autopsier",
        "Asistent Farmacist",
        "Laborant Farmacie",
        "Tehnician Protezist-Ortezist",
        "Tehnician Acustician-Audioprotezist",
        "Evaluator Asigurari",
        "Laborant In Ocrotirea Sanatatii",
        "Sora Medicala",
        "Asistenta Puericultoare",
        "Mercantizor",
        "Agent Veterinar",
        "Asistent Veterinar",
        "Autopsier La Ecarisaj",
        "Tehnician Veterinar",
        "Tehnician Dentar",
        "Asistent Medical Comunitar",
        "Optician Medical",
        "Optometrist (Studii Medii)",
        "Maseur",
        "Asistent Medical Fizioterapie",
        "Ergoterapeut",
        "Reflexoterapeut",
        "Oficiant Medical",
        "Tehnician Sanitar",
        "Asistent Medical Consiliere Hiv/Sida",
        "Manager Al Sistemelor De Management Al Calitatii",
        "Manager Al Sistemelor De Management De Mediu",
        "Auditor De Mediu",
        "Expert/Specialist Standardizare",
        "Monitor Mediul Inconjurator",
        "Inspector Pentru Conformare Ecologica",
        "Asistent Standardizare",
        "Manager Al Sistemului De Management Al Riscului",
        "Manager Al Sistemului De Management Securitate Si Sanatate In Munca",
        "Responsabil De Mediu",
        "Auditor De Sistem De Management Pentru Sanatate Si Securitate Ocupationala",
        "Inspector Protectia Mediului",
        "Specialist In Managementul Deseurilor",
        "Auditor In Domeniul Sigurantei Alimentare",
        "Manager In Domeniul Sigurantei Alimentare",
        "Auditor Responsabilitate Sociala",
        "Responsabil Al Managementului Responsabilitatii Sociale",
        "Manager De Responsabilitate Sociala",
        "Inspector Sanitar",
        "Inspector Protectie Sociala",
        "Tehnician In Securitate Si Sanatate In Munca",
        "Tehnician Conditii De Munca Si Securitate",
        "Inspector In Domeniul Securitatii Si Sanatatii In Munca",
        "Coordonator In Materie De Securitate Si Sanatate In Munca (Studii Medii)",
        "Operator Control Nedistructiv Pentru Examinare Vizuala",
        "Brancardier",
        "Cambist (Broker Valori)",
        "Agent De Schimb",
        "Intermediar In Activitatea Financiara Si Comerciala (Broker)",
        "Broker Bursa De Marfuri",
        "Agent De Vanzari Directe (Produse Financiar-Bancare)",
        "Teleoperator Financiar-Bancar",
        "Agent Marketing Pensii Private",
        "Analist Tehnic Piete Financiare",
        "Ofiter Operatiuni Financiar-Bancare",
        "Calculator Devize",
        "Contabil",
        "Tehnician Merceolog",
        "Planificator",
        "Revizor Gestiune",
        "Contabil Bugetar",
        "Secretar Economic (Studii Medii)",
        "Merceolog",
        "Referent",
        "Referent Statistician",
        "Statistician",
        "Statistician Medical",
        "Actuar",
        "Tehnician Planificare/Urmarire Sinteze",
        "Estimator Licitatii",
        "Evaluator Tehnic Daune Auto",
        "Agent De Asigurare",
        "Broker In Asigurari",
        "Reprezentant Tehnic",
        "Reprezentant Comercial",
        "Agent De Vanzari",
        "Agent Comercial",
        "Agent Vanzari Standarde Si Produse Conexe",
        "Agent Contractari Si Achizitii (Broker Marfuri)",
        "Receptioner Contractari-Achizitii",
        "Administrator Cumparari",
        "Agent Cumparari",
        "Declarant Vamal",
        "Agent Tranzit",
        "Agent Maritim",
        "Agent Repartizare A Fortei De Munca",
        "Agent Orientare Profesionala A Somerilor/Agent Informare Privind Cariera",
        "Agent Evidenta Si Plata A Ajutorului De Somaj",
        "Inspector/Referent Resurse Umane",
        "Agent Ocupare",
        "Analist Resurse Umane",
        "Tehnician Mobilitate Personal",
        "Tehnician Reconversie Personal",
        "Instructor/Preparator Formare",
        "Tehnician Calificare Gestiune Competente",
        "Tehnician Resurse Umane",
        "Agent Imobiliar (Broker Imobiliar)",
        "Agent Reclama Publicitara",
        "Agent Literar",
        "Impresar Muzical",
        "Impresar Teatru",
        "Manager Sportiv",
        "Asistent Relatii Publice Si Comunicare (Studii Medii)",
        "Agent Servicii Client",
        "Impresar Artistic",
        "Organizator Spectacole",
        "Operator De Interviu",
        "Referent Comert Exterior",
        "Operator Vanzari Prin Telefon",
        "Secretar Procuratura",
        "Secretar Administrativ",
        "Secretar Asistent Director",
        "Asistent Manager",
        "Asistent De Cabinet",
        "Registrator Medical",
        "Controlor Vamal, Controlor Pentru Datoria Vamala (Studii Medii)",
        "Revizor Vamal",
        "Referent Tir Si Tranzite (Studii Medii)",
        "Referent Vamal (Studii Medii)",
        "Expert/Inspector Vamal",
        "Controlor Vamal, Controlor Pentru Datoria Vamala, Agent Vamal (Studii Superioare)",
        "Inspector De Trafic A.R.R. (Studii Medii)",
        "Inspector Taxe Si Impozite",
        "Operator Rol",
        "Perceptor",
        "Inspector Pensii, Asigurari Sociale Si Asistenta Sociala",
        "Referent Pensii, Asigurari Sociale Si Asistenta Sociala",
        "Inspector Pentru Acordarea De Permise, Licente Sauautorizatii",
        "Inspector De Politie",
        "Detectiv",
        "Anchetator Politie",
        "Detectiv Particular",
        "Inspector Metrolog",
        "Inspector Preturi",
        "Inspector Salarii",
        "Comisar",
        "Agent Procedural",
        "Conducator Carte Funciara",
        "Grefier",
        "Secretar Notariat",
        "Tehnician Criminalist",
        "Functionar In Activitati Comerciale, Administrative Si Preturi",
        "Executor Judecatoresc (Tribunal, Judecatorie)",
        "Arhivar Notariat",
        "Grefier Dactilograf (Curtea De Apel, Tribunal, Judecatorie)",
        "Grefier Statistician",
        "Grefier Documentarist",
        "Secretar Dactilograf Laborator Expertize Criminalistice",
        "Asistent Registrator",
        "Grefier Arhivar",
        "Grefier Registrator",
        "Ofiter Antifrauda Financiar-Bancara (Studii Medii)",
        "Asistent Social Nivel Mediu",
        "Pedagog Social",
        "Lucrator Social Pentru Persoane Cu Probleme De Dependenta",
        "Facilitator De Dezvoltare Comunitara",
        "Lucrator De Tineret",
        "Calugar",
        "Calugarita",
        "Predicator",
        "Fotbalist Profesionist",
        "Sportiv Profesionist In Alte Discipline Sportive",
        "Jucator De Rugbi",
        "Antrenor",
        "Instructor Sportiv",
        "Secretar Federatie",
        "Antrenor De Fotbal Profesionist",
        "Instructor Arte Martiale",
        "Instructor (Monitor) Schi/Calarie/Golf/Tenis/ Inot/Sporturi Extreme",
        "Antrenor Coordonator",
        "Arbitru Judecator Sportiv",
        "Preparator Sportiv",
        "Impresar Sportiv",
        "Oficial Sportiv Acreditat",
        "Instructor In Poligonul De Tir",
        "Supraveghetor In Poligonul De Tir",
        "Monitor De Schi, Snow-Board Si Sporturi De Alunecare Pe Zapada",
        "Instructor Educatie Acvatica",
        "Animator Sportiv",
        "Instructor De Fitness",
        "Antrenor De Fitness",
        "Instructor De Aerobic-Fitness",
        "Instructor Educatie Fizica",
        "Fotograf",
        "Laborant Foto",
        "Retusor Foto",
        "Operator Prelucrare Pelicula",
        "Fotograf Si Tehnician La Echipamente De Inregistrare Imagine Si Sunet",
        "Butafor",
        "Decorator Interioare",
        "Desenator Artistic (Studii Medii)",
        "Decorator Vitrine",
        "Desenator Artistic (Studii Superioare)",
        "Sef De Sala Restaurant",
        "Barman-Sef",
        "Bucatar-Sef",
        "Cofetar-Sef",
        "Inspector Calitate Productie Culinara",
        "Manuitor, Montator Decor",
        "Tehnician Machetist",
        "Tehnician Reclame (Decorator)",
        "Maestru De Lumini",
        "Maestru De Sunet",
        "Caricaturist (Studii Medii)",
        "Tehnoredactor",
        "Secretar De Redactie (Studii Medii)",
        "Organizator De Productie",
        "Asistent Regizor Artistic",
        "Reporter (Studii Medii)",
        "Machior Spectacole",
        "Peruchier",
        "Secretar De Emisie (Studii Medii)",
        "Ghid De Animatie",
        "Documentarist (Studii Medii)",
        "Traducator (Studii Medii)",
        "Videojurnalist (Studii Medii)",
        "Copywriter Publicitate (Studii Medii)",
        "Corector (Studii Medii)",
        "Electrician Iluminare Scena",
        "Secretar Artistic",
        "Operator Calculator Electronic Si Retele",
        "Sef Tura Exploatare In Centre Sau Oficii De Calcul",
        "Tehnician Echipamente De Calcul Si Retele",
        "Operator In Domeniul Proiectarii Asistate Pe Calculator",
        "Administrator Sistem Documentar",
        "Operator Prompter",
        "Operator Suport Tehnic Pentru Servicii De Comunicatii Electronice",
        "Programator Ajutor",
        "Analist Ajutor",
        "Acustician Cinematografic",
        "Controlor Si Reconditioner Filme",
        "Electrician Iluminare Filmare",
        "Etaloner",
        "Maistru Aparate Video Si Sunet",
        "Masinist Mecanic Traweling",
        "Mecanic Camera Filmare",
        "Montor Imagine",
        "Montor Negative Si De Pregatire A Peliculei",
        "Montor Pozitive",
        "Operator Camera Diafilm, Diapozitive",
        "Operator Emisie-Receptie",
        "Operator Productie Rtv",
        "Preparator Filmare",
        "Proiectionist",
        "Senzitometrist",
        "Stantator De Filme",
        "Operator Truka",
        "Editor Imagine",
        "Tehnician Iluminat Tehnologic",
        "Ilustrator Muzical",
        "Controlor Emisii Rtv",
        "Montor Emisie",
        "Operator Imagine",
        "Operator Radio-Radioficare",
        "Operator Sunet",
        "Tehnician Radioelectronist",
        "Tehnician Catv",
        "Operator Dispecer Sisteme De Monitorizare Si Aparatura De Control",
        "Tehnician Pentru Sisteme De Detectie, Supraveghere Video, Control Acces",
        "Cameraman",
        "Tehnician De Echipamente Tv",
        "Radioelectronist Statii De Emisie Radio-Tv",
        "Tehnician La Echipamente De Inregistrare Imagine Si Sunet",
        "Designer Video",
        "Sef Formatie Sisteme Radiante (Antene)",
        "Tehnician Constructii Telefonice",
        "Tehnician Radiolocatii",
        "Tehnician Turn Parasutism",
        "Inspector Exploatare Postala",
        "Tehnician Statii De Emisie Radio-Tv",
        "Tehnician Statii Radiorelee Si Satelit",
        "Maistru Materiale Emisie Rtv Si Telecomunicatii",
        "Pilonist Antenist",
        "Tehnician Retele De Telecomunicatii",
        "Operator Retele De Telecomunicatii",
        "Radioelectronist Statii Radiorelee Si Satelit",
        "Maistru Transporturi, Posta Si Telecomunicatii",
        "Tehnician Transporturi, Posta Si Telecomunicatii",
        "Tehnician Proiectant Transporturi Si Comunicatii",
        "Functionar Administrativ",
        "Inspector Documente Secrete",
        "Secretara",
        "Secretara Dactilografa",
        "Secretara Prelucrare Texte",
        "Dactilografa",
        "Stenodactilografa",
        "Referent Transmitere",
        "Telefaxist",
        "Teletipist",
        "Telexist",
        "Telebanker",
        "Operator Introducere, Validare Si Prelucrare Date",
        "Operator Tehnica Poligraf",
        "Operator Procesare Text Si Imagine",
        "Registrator De Arhiva Electronica De Garantii Reale Mobiliare",
        "Operator Masina Contabilizat",
        "Operator Masina De Calculat",
        "Casier Tezaur",
        "Casier Valuta",
        "Manuitor Valori (Presa, Posta)",
        "Numarator Bani",
        "Verificator Bani",
        "Verificator Valori",
        "Casier Trezorier",
        "Sef Casierie Centrala",
        "Sef Supraveghere Case",
        "Operator Ghiseu Banca",
        "Operator Ghiseu Birouri De Schimb",
        "Administrator Cont",
        "Referent Operatii Intre Sedii",
        "Referent Casier",
        "Crupier",
        "Schimbator Fise ",
        "Supraveghetor Jocuri (Cazino)",
        "Sef De Masa (Cazino)",
        "Cap De Masa (Cazino)",
        "Amanetar",
        "Agent Fiscal",
        "Colector (Recuperator) Creante/Debite",
        "Agent De Voiaj",
        "Agent De Turism",
        "Agent De Turism Tour-Operator",
        "Agent De Transport Turistic Intern",
        "Agent De Transport International",
        "Agent De Asistenta Turistica",
        "Agent Turism De Afaceri",
        "Agent Transporturi Externe",
        "Agent Transporturi Interne",
        "Functionar Agentie Voiaj",
        "Oficiant Telefoane",
        "Oficiant Telegraf",
        "Radiotelegrafist",
        "Telefonist",
        "Telefonist Instructor",
        "Telegrafist (Teleimprimatorist)",
        "Receptioner De Hotel",
        "Lucrator Concierge",
        "Sef De Receptie Hotel",
        "Tehnician Compartiment Securitate Hotel",
        "Responsabil Cazare",
        "Impiegat Informatii",
        "Functionar Informatii Clienti",
        "Receptionist",
        "Calculator Pret Cost",
        "Functionar Economic",
        "Operator Devize",
        "Sef Sectie Inventar",
        "Agent Bursa",
        "Contabil Financiar Bancar",
        "Administrator Financiar (Patrimoniu) ",
        "Pontator",
        "Gestionar Depozit",
        "Magaziner",
        "Operator Siloz (Silozar)",
        "Primitor-Distribuitor Materiale Si Scule",
        "Recuziter",
        "Sortator Produse",
        "Trezorier (Studii Medii)",
        "Gestionar Custode Sala",
        "Pivnicer",
        "Primitor-Distribuitor Benzina Si Motorina",
        "Lucrator Gestionar",
        "Sef Raion/Adjunct Marfuri Alimentare/Nealimentare",
        "Dispecer",
        "Facturist",
        "Lansator Produse",
        "Programator Productie",
        "Dispecer Operatiuni Salubrizare",
        "Agent Transporturi",
        "Functionar Informatii",
        "Controlor Trafic",
        "Impiegat Auto",
        "Impiegat Informatii Aviatie",
        "Impiegat Registru Miscare",
        "Insotitor Vagoane",
        "Inspector Rnr (Registru Naval Roman)",
        "Inspector Exploatare Trafic",
        "Instructor Depou",
        "Instructor Revizie Vagoane",
        "Instructor Statie",
        "Operator Circulatie Miscare",
        "Operator Comercial",
        "Operator Dana",
        "Operator Programare",
        "Picher",
        "Reditionar",
        "Revizor Tehnic Vagoane",
        "Scriitor Vagoane",
        "Sef Agentie Colectare Si Expeditie Marfuri",
        "Sef Autogara",
        "Avizier Cai Ferate",
        "Sef Halta",
        "Sef Statie Taxare",
        "Sef Tura La Comanda Personalului De Tren",
        "Sef Tura Pregatirea Personalului La Vagon-Restaurant Si De Dormit",
        "Sef Tura Revizie Vagoane",
        "Veghetor Incarcare-Descarcare",
        "Verificator Documente Expeditie",
        "Expeditor International",
        "Operator Receptie",
        "Agent Curier",
        "Agent Statie Metrou",
        "Impiegat De Miscare Metrou",
        "Operator Miscare Metrou",
        "Operator Portuar Stivator",
        "Operator Portuar Expeditor",
        "Operator Portuar Dispecer/Planificator",
        "Grafician Mers De Tren",
        "Referent De Specialitate Tir Si Tranzite (Studii Superioare)",
        "Agent Feroviar Marfa",
        "Bibliotecar (Studii Medii)",
        "Discotecar",
        "Filmotecar",
        "Fonotecar",
        "Fototecar",
        "Manuitor Carte",
        "Videotecar",
        "Agent Postal",
        "Cartator Postal",
        "Cartator Presa",
        "Cartator Telegrame",
        "Diriginte Posta",
        "Factor Postal",
        "Inspector Telegrame",
        "Oficiant Posta Telegrame",
        "Oficiant Presa",
        "Prelucrator Presa Scrisa",
        "Responsabil Tura Expeditie",
        "Sef Vagon Postal",
        "Codificator",
        "Corector Editura Presa",
        "Corector-Revizor Poligrafie",
        "Arhivar",
        "Functionar Documentare",
        "Restaurator Arhiva (Studii Medii)",
        "Conservator Arhiva (Studii Medii)",
        "Restaurator Opere De Arta Si Monumente Istorice (Studii Medii)",
        "Conservator Opere De Arta Si Monumente Istorice (Studii Medii)",
        "Restaurator Bunuri Culturale (Studii Medii)",
        "Conservator Bunuri Culturale",
        "Referent Evidenta Persoanelor",
        "Functionar Ghiseu Servicii Publice",
        "Expert Local Pe Problemele Romilor",
        "Insotitor De Bord",
        "Stewardesa",
        "Conductor Tren",
        "Revizor Bilete",
        "Controlor Bilete",
        "Conductor Vagon De Dormit Si Cuseta",
        "Controlor Acces Metrou",
        "Sef Tura Comanda Vagon De Dormit ",
        "Ghid De Turism",
        "Ghid De Turism Intern (Local)",
        "Ghid National De Turism (Tour-Operator)",
        "Ghid De Turism Montan, Drumetie Montana",
        "Ghid Galerii De Arta/Interpret",
        "Ghid Habitat Natural Flora, Fauna",
        "Ghid Turism Ornitologic",
        "Ghid Turism Speologic",
        "Ghid Turism Ecvestru",
        "Ghid De Turism Sportiv ",
        "Ghid Montan",
        "Ghid Obiectiv Cultural",
        "Insotitor Grup Turistic",
        "Organizator Activitate Turism (Studii Medii)",
        "Ranger",
        "Custode Pentru Arii Protejate",
        "Animator De Hotel",
        "Bucatar",
        "Pizzar",
        "Bucatar Specialist/Vegetarian/Dietetician",
        "Maestru In Arta Culinara",
        "Ajutor Ospatar",
        "Ospatar (Chelner)",
        "Somelier",
        "Barman",
        "Barman Preparator",
        "Coafor",
        "Frizer",
        "Cosmetician",
        "Manichiurist",
        "Pedichiurist",
        "Maseur De Intretinere Si Relaxare",
        "Machior",
        "Tatuator",
        "Montator Bijuterii Pe Corp",
        "Stilist Protezist De Unghii",
        "Cabanier",
        "Guvernanta De Hotel/Etaj",
        "Lenjereasa De Hotel",
        "Administrator",
        "Administrator Piete Si Targuri",
        "Intendent",
        "Sef Cantina",
        "Dispecer Pentru Servire In Camera (Hotel)",
        "Gospodar",
        "Ingrijitor Vila",
        "Administrator Pensiune Turistica",
        "Lucrator In Gospodaria Agroturistica",
        "Ingrijitor Cladiri",
        "Agent Curatenie Cladiri Si Mijloace De Transport",
        "Administrator Imobile",
        "Astrolog",
        "Camerista Hotel",
        "Insotitor",
        "Valet",
        "Antreprenor Servicii Funerare",
        "Decorator Servicii Funerare",
        "Imbalsamator",
        "Ingrijitor Farmacii, Cabinete Veterinare",
        "Coafor Canin",
        "Instructor Scolar Auto",
        "Instructor Auto",
        "Agent Dezinfectie, Deratizare, Dezinsectie",
        "Gazda Club",
        "Organizator Prestari Servicii",
        "Agent Ecolog",
        "Raportor Ecolog",
        "Intretinator Textile-Piele",
        "Animator Socioeducativ",
        "Animator Centre De Vacanta",
        "Lucrator Pensiune Turistica",
        "Operator Partie De Schi",
        "Vanzator Ambulant De Produse Alimentare",
        "Vanzator",
        "Anticar",
        "Librar",
        "Lucrator Controlor Final",
        "Lucrator Comercial",
        "Lucrator Produse Naturiste",
        "Vanzator De Produse Naturiste",
        "Taxator",
        "Vanzator De Bilete",
        "Casier",
        "Casier Metrou",
        "Manechin",
        "Model ",
        "Prezentator Moda",
        "Vanzator La Domiciliul Clientului Pe Baza De Comanda",
        "Bufetier",
        "Ingrijitor De Copii",
        "Guvernanta",
        "Babysitter",
        "Asistent Maternal",
        "Parinte Social",
        "Educator Specializat",
        "Baies",
        "Gipsar",
        "Infirmier/Infirmiera",
        "Ingrijitoare La Unitati De Ocrotire Sociala Si Sanitara",
        "Lacar",
        "Namolar",
        "Ingrijitor Batrani La Domiciliu",
        "Ingrijitor Bolnavi La Domiciliu",
        "Asistent Personal Al Persoanei Cu Handicap Grav",
        "Ingrijitor La Domiciliu",
        "Mediator Sanitar",
        "Mediator Social",
        "Lucrator Prin Arte Combinate",
        "Asistent Personal Profesionist",
        "Asistent Personal De Ingrijire",
        "Operator Prestatii Sociale",
        "Supraveghetor De Noapte Servicii Sociale",
        "Lucrator Social",
        "Sef Compartiment Pentru Prevenire",
        "Sef Formatie Interventie, Salvare Si Prim Ajutor",
        "Specialisti Pentru Prevenire",
        "Servant Pompier",
        "Sef Grupa Interventie",
        "Sef Echipa Specializata",
        "Agent Politie Comunitara",
        "Gardian De Inchisoare",
        "Educator In Penitenciare",
        "Agent De Securitate",
        "Agent Control Acces",
        "Agent De Securitate Incinta (Magazin, Hotel, Intreprindere Etc.)",
        "Agent Garda De Corp",
        "Sef Formatie Paza Si Ordine",
        "Agent De Interventie Paza Si Ordine",
        "Agent Transport Valori",
        "Dispecer Centru De Alarma",
        "Sef Tura Servicii Securitate",
        "Inspector De Securitate",
        "Evaluator De Risc De Efractie",
        "Consultant De Securitate",
        "Agent Cu Atributii Pe Linia Ordinii Si Sigurantei Publice In Incinta Arenelor Sportive",
        "Sef Serviciu Voluntar/Privat Pentru Situatii De Urgenta",
        "Cadru Tehnic Cu Atributii In Domeniul Prevenirii Si Stingerii Incendiilor",
        "Salvator La Strand",
        "Salvator Montan",
        "Salvamar",
        "Gardian Feroviar",
        "Agent Conducator Caini De Serviciu",
        "Agricultor",
        "Gradinar",
        "Legumicultor",
        "Lucrator Calificat In Culturi De Camp Si Legumicultura",
        "Agricultor Pentru Culturi De Camp Ecologice",
        "Arboricultor",
        "Ciupercar",
        "Florar-Decorator",
        "Floricultor",
        "Peisagist-Floricultor",
        "Lucrator Calificat In Floricultura Si Arboricultura",
        "Pomicultor",
        "Viticultor",
        "Fermier In Horticultura",
        "Cioban (Oier)",
        "Crescator-Ingrijitor De Animale Domestice Pentru Productia De Lapte Si Carne",
        "Tocator De Furaje",
        "Lucrator Calificat In Cresterea Animalelor",
        "Crescator Bovine",
        "Crescator Porcine",
        "Mamos Porcine",
        "Baci Montan",
        "Cioban Montan",
        "Crescator De Oi Montan",
        "Oier Montan",
        "Crescator De Pasari",
        "Fazanier",
        "Apicultor",
        "Sericicultor",
        "Crescator De Animale Mici",
        "Crescator-Ingrijitor Animale Salbatice Captive",
        "Crescator-Ingrijitor De Animale De Laborator",
        "Crescator De Melci",
        "Antrenor Cabaline",
        "Crescator-Ingrijitor De Cabaline",
        "Herghelegiu",
        "Fermier In Productia Vegetala",
        "Fermier In Productia Animala",
        "Agricultor In Culturi Vegetale Si Crescator De Animale",
        "Cioplitor In Lemn",
        "Carbonitor",
        "Fasonator Mecanic (Cherestea)",
        "Muncitor Plantatii Si Amenajare Zona Verde",
        "Pepinierist",
        "Presator Stuf",
        "Protectionist Silvic",
        "Recoltator Stuf",
        "Rezinator",
        "Sef Coloana Exploatare Stuf",
        "Stivuitor Si Receptioner Silvic",
        "Taietor Silvic",
        "Preparator Mangal",
        "Mangalizator",
        "Lucrator In Culturi Acvatice",
        "Piscicultor",
        "Pescar In Ape Interioare Si De Coasta",
        "Pescar In Mari Si Oceane",
        "Paznic De Vanatoare",
        "Muncitor Constructor Barne, Chirpici, Piatra",
        "Confectioner Placi Din Diverse Materiale",
        "Confectioner Plase Si Panze Rabit Din Stuf",
        "Sobar",
        "Zidar Cosuri Fabrica",
        "Zidar Pietrar",
        "Zidar Samotor",
        "Zidar Rosar-Tencuitor",
        "Zidar Restaurator",
        "Cioplitor In Piatra Si Marmura",
        "Cioplitor-Montator Piatra, Marmura",
        "Gaterist La Taiat Blocuri De Piatra, Marmura",
        "Taietor, Slefuitor, Lustruitor Piatra, Marmura",
        "Restaurator Piatra",
        "Betonist",
        "Fierar Betonist",
        "Montator Elemente Prefabricate Din Beton Armat",
        "Constructor Structuri Monolite",
        "Operator Injectorist",
        "Injectorist In Constructii",
        "Dulgher (Exclusiv Restaurator)",
        "Dulgher Restaurator",
        "Muncitor Hidrometru",
        "Pavator",
        "Sapator Fantani",
        "Asfaltator",
        "Cantonier",
        "Chesonier",
        "Constructor Cai Ferate",
        "Constructor Linii Tramvai",
        "Drenor Canalist",
        "Fascinar",
        "Finisor Terasamente",
        "Muncitor Hidrogeolog",
        "Muncitor Constructor Senal Navigabil, Lucrari Hidrotehnice Si Portuare",
        "Sef Echipa Intretinere Poduri Metalice, Viaducte Si Tuneluri",
        "Agent Hidrotehnic",
        "Revizor Cale Sau Puncte Periculoase",
        "Meserias Intretinere Cale",
        "Sef Echipa Intretinere Cale",
        "Meserias Intretinere Poduri Metalice, Viaducte Si Tuneluri",
        "Alpinist Utilitar",
        "Laborant Determinari Fizico-Mecanice Pentru Lucrari De Drumuri Si Poduri",
        "Sef Echipa Intretinere Cale Metrou",
        "Sef Echipa Lucrari Arta Metrou",
        "Lucrator Pentru Drumuri Si Cai Ferate",
        "Muncitor In Taieri Structuri Cu Scule Diamantate",
        "Acoperitor-Invelitor Tigla, Azbociment, Tabla",
        "Constructor De Acoperisuri",
        "Faiantar",
        "Montator Placaje Interioare Si Exterioare",
        "Mozaicar (Exclusiv Restaurator)",
        "Parchetar",
        "Mozaicar Restaurator",
        "Linolist",
        "Montator Placaje Uscate",
        "Ipsosar (Exclusiv Restaurator)",
        "Turnator Ornamentalist",
        "Ipsosar Restaurator Ornamente Din Ipsos",
        "Izolator Fonic",
        "Izolator Frigorific",
        "Izolator Hidrofug",
        "Izolator Lucrari Speciale (Antiacide Si De Protectie)",
        "Izolator Termic",
        "Montator Pereti Si Plafoane Din Ghips-Carton",
        "Asamblator-Montator Profile Aluminiu Si Geam Termopan",
        "Confectioner Geam Termoizolator",
        "Confectioner Tamplarie Din Aluminiu Si Mase Plastice",
        "Montator Tamplarie Din Aluminiu Si Mase Plastice",
        "Confectioner-Montator Tamplarie Din Aluminiu Si Mase Plastice Cu Geam Termoizolator",
        "Montator Materiale Geosintetice",
        "Sudor Geomembrana",
        "Montator Geogrile",
        "Montator Materiale Geotextile Si Geocompozite",
        "Geamgiu",
        "Detector Pierderi Apa Si Gaze",
        "Instalator Apa, Canal",
        "Instalator Frigotehnist",
        "Instalator Incalzire Centrala Si Gaze",
        "Instalator Retele De Distributie/Transport Fluide",
        "Instalator Ventilare Si Conditionare Apa",
        "Verificator Canale Subterane",
        "Instalator Centrale Termice",
        "Instalator Instalatii Tehnico-Sanitare Si De Gaze",
        "Instalator Autorizat Proiectare Executie Si/Sau Exploatare Obiectiv/Sisteme De Transport",
        "Instalator Autorizat Proiectare Executie Si/Sau Exploatare Obiectiv/Sisteme De Distributie",
        "Instalator Retele Termice Si Sanitare",
        "Operator Instalatii Apa Si Canalizare",
        "Frigoriferist (Frigotehnist)",
        "Tapetar",
        "Zugrav",
        "Stucaturist",
        "Ignifugator",
        "Operator Termoprotectie",
        "Lacuitor Lemn",
        "Vopsitor Industrial",
        "Finisor-Lacuitor Lemn",
        "Vopsitor",
        "Vopsitor Auto",
        "Cosar",
        "Curatitor De Fatade",
        "Modelier Lemn",
        "Modelier Metal",
        "Modelator-Miezuitor",
        "Modelier Naval",
        "Operator La Masini De Brichetat Span",
        "Pregatitor Metale Vechi Pentru Retopire",
        "Recuperator Metale Vechi",
        "Topitor Aliaje Tipografie",
        "Topitor Fonta Si Neferoase",
        "Topitor, Turnator Metale Si Aliaje Neferoase",
        "Turnator Fonta Pe Banda",
        "Turnator Formator",
        "Turnator Pregatitor Otelarie",
        "Turnator Modelier",
        "Turnator Metale Si Neferoase",
        "Modelor Prototipuri Auto",
        "Brazor",
        "Sudor Manual Cu Flacara De Gaze",
        "Sudor Manual Cu Arc Electric",
        "Sudor Cu Arc Electric Acoperit Sub Strat De Flux",
        "Operator Taiere",
        "Sudor Cu Arc Electric Cu Electrod Fuzibil In Mediu De Gaz Protector",
        "Sudor Cu Arc Electric Cu Electrod Nefuzibil In Mediu De Gaz Protector",
        "Sudor",
        "Cazangiu Recipiente",
        "Probator Hidraulic Cazane, Tevi, Recipiente",
        "Tinichigiu Carosier",
        "Tinichigiu Industrial",
        "Tinichigiu De Santier",
        "Tinichigiu Structurist De Aviatie",
        "Cazangiu Tevar",
        "Cazangiu Formator",
        "Tinichigiu Restaurator",
        "Tinichigiu Sisteme De Acoperisuri Si Invelitori",
        "Tinichigiu Sisteme De Ventilatie",
        "Tinichigiu In Constructii",
        "Finisor Cocleti",
        "Finisor Ace Si Accesorii",
        "Confectioner Capace De Carde",
        "Confectioner Cocleti",
        "Confectioner Plase Din Sarma",
        "Formator Tevi Prin Sudare",
        "Lacatus Constructii Metalice Si Navale",
        "Lacatus De Mina",
        "Lacatus Revizie Vagoane",
        "Lacatus Mecanic",
        "Lacatus-Montator",
        "Presator Metale La Rece",
        "Reconditioner Scule Si Utilaje Petroliere",
        "Sanfrenator",
        "Pregatitor, Montator, Reparator Ite, Cocleti, Lamele, Spete",
        "Repasator Garnituri Carde",
        "Tubulator Naval",
        "Masinist La Litografiat Si Vernisat Tabla",
        "Masinist La Confectionarea Ambalajelor Metalice",
        "Masinist La Confectionarea Tuburilor De Aluminiu",
        "Constructor-Montator De Structuri Metalice",
        "Masinist La Fabricarea Acelor Si Accesoriilor",
        "Nituitor",
        "Lacatus Mecanic De Intretinere Si Reparatii Universale",
        "Masinist La Confectionarea Spetelor Si Spiralelor",
        "Montator-Ajustor Spete",
        "Lipitor Si Protejator Spete",
        "Taietor Garnituri De Carde",
        "Masinist Mecanic La Confectionare Garnituri Carde",
        "Lacatus-Depanator Utilaje Calcul",
        "Operator La Montarea Si Conservarea Produselor Dupa Probe",
        "Schelar",
        "Confectioner-Montator Structuri Metalice Pentru Constructii",
        "Montator Fatade Si Pereti Cortina",
        "Mecanic-Montator Instalatii Cu Cablu In Silvicultura Si Exploatari Forestiere",
        "Forjor-Matriter",
        "Prelucrator Mecanic Metale Pretioase",
        "Presator Piese Din Pulberi Metalice",
        "Stantator",
        "Presator, Ambutisor La Cald",
        "Forjor Manual",
        "Forjor-Arcurar",
        "Forjor Mecanic",
        "Confectioner Ferodouri",
        "Preparator Pulberi",
        "Cuptorar-Termist Pentru Ferite",
        "Fierar/Potcovar",
        "Formator-Presator Ferite",
        "Finisor Ferite",
        "Controlor De Calitate La Forjare",
        "Controlor De Calitate La Turnare",
        "Debitator-Ebosator",
        "Dusisator-Polizator",
        "Lacatus Sdv",
        "Sculer-Matriter",
        "Lacatus Amc",
        "Lacatus Mecanica Fina",
        "Prelucrator Prin Electroeroziune",
        "Lacatus La Prelucrarea Si Indreptarea Tevilor Ghintuite",
        "Reglor La Masini Pentru Fabricarea Cablurilor, Conductorilor Electrici Si Materialelor Electrice",
        "Reglor La Masini Pentru Confectionarea Elementelor Galvanice",
        "Reglor Benzi Montaj",
        "Masinist La Linii Automate Aschietoare",
        "Reglor Masini De Bobinat Si Platinat",
        "Reglor La Masini De Prelucrare Mase Plastice",
        "Reglor Masini-Unelte",
        "Reglor-Montator",
        "Reglor La Masini Pentru Fabricarea Lampilor Electrice",
        "Reglor Si Reglor-Conductor La Masini-Unelte",
        "Conductor De Instalatii",
        "Operator La Masini-Unelte Semiautomate Si Automate",
        "Dozator La Fabricarea Electrozilor De Sudura",
        "Masinist La Lame De Masini Pentru Automate Aschietoare",
        "Degresator-Imersioner",
        "Uscator Electrozi De Sudura",
        "Masinist La Masini Speciale Fara Aschiere",
        "Preparator Amestec De Invelis",
        "Pregatitor Sarma",
        "Finisator Electrozi De Sudura",
        "Masinist La Masini Speciale De Aschiere",
        "Masinist La Confectionarea Tuburilor De Protectie Si A Dozelor De Ramificatie",
        "Operator La Masini-Unelte Cu Comanda Numerica",
        "Operator La Masini De Electroeroziune Automate",
        "Ascutitor Laminate La Cald",
        "Ascutitor Laminate La Rece",
        "Ascutitor-Calitor Garnituri De Carde",
        "Ascutitor Scule, Instrumente Medicale Si Obiecte De Uz Casnic",
        "Debitator-Slefuitor Perii De Masini Electrice",
        "Polizator",
        "Slefuitor Metale",
        "Frezor Universal",
        "Gauritor-Filetator",
        "Honuitor, Rodator-Lepuitor",
        "Rabotor-Mortezor Universal",
        "Rectificator Universal",
        "Strungar Universal",
        "Brosator",
        "Frezor La Masini Roti Dintate",
        "Gravor Mecanic",
        "Rabotor, Mortezor Roti Dintate",
        "Rectificator Dantura Caneluri",
        "Strungar La Strung Paralel Si De Detalonat",
        "Strungar La Strung Revolver",
        "Strungar La Strung Carusel",
        "Strungar La Masini Orizontale",
        "Strungar La Masini De Alezat",
        "Strungar La Masini De Prelucrat In Coordonate",
        "Strungar La Masini De Strunjit Roti Cai Ferate",
        "Rectificator Piese Producatoare De Ochiuri",
        "Slefuitor Metale Cu Plumb Industria De Armament",
        "Debitator Semifabricate",
        "Curatitor-Sablator",
        "Electrician Auto",
        "Electromecanic Auto",
        "Mecanic Auto",
        "Operator Standuri Incercari",
        "Operator Pregatire Incercari Vehicule",
        "Mecanic Aviatie",
        "Lacatus-Montator Agregate Energetice Si De Transport",
        "Mecanic Utilaj",
        "Mecanic Agricol",
        "Motorist",
        "Ungator-Gresor",
        "Operator In Verificarea, Reincarcarea Si Repararea Stingatoarelor De Incendiu",
        "Mecanic Intretinere Si Reparatii Masini De Cusut Industriale",
        "Operator In Verificarea, Intretinerea Si Repararea Autospecialelor Destinate Apararii Impotriva Incendiilor",
        "Mecanic Masini Agricole",
        "Mecanic Trolist",
        "Amc-Ist",
        "Armurier",
        "Blocator, Chituitor, Deblocator",
        "Ceasornicar",
        "Centrator, Debordator Piese Optice",
        "Centrator, Finisor Aparate Optice",
        "Degresator, Curatator Piese Si Aparate Optice",
        "Lipitor Lentile Si Prisme",
        "Montator Aparatura Optica",
        "Optician",
        "Optician Armament",
        "Confectioner Seringi",
        "Presator Piese Optice",
        "Reparator Aparate Foto",
        "Reparator Stilouri, Brichete",
        "Reparator Umbrele",
        "Gravor Piese Optice",
        "Tratamentist Piese Optice",
        "Metrolog Si Depanator Mecanica Fina, Tehnica Digitala Si Analogica (Mftda)",
        "Metrolog Verificator",
        "Acordor Acordeoane, Armonici",
        "Acordor Piane, Pianine, Orga, Tambal",
        "Caserator Si Slefuitor De Celuloid Pentru Carcase Acordeoane",
        "Ceruitor De Piastrine Pentru Acordeoane",
        "Constructor Claviatura",
        "Constructor-Reparator De Acordeoane Si Armonici",
        "Constructor-Reparator De Alte Instrumente Muzicale (Suflat, Percutie)",
        "Filator Corzi Pentru Piane",
        "Montator Corp Sonor La Piane",
        "Montator-Reglor Piane",
        "Montator-Ajustor De Acordeoane",
        "Lutier",
        "Constructor Restaurator De Orgi",
        "Argintar",
        "Bijutier Metale Pretioase",
        "Cizelator",
        "Cizelator Clisee Galvanice",
        "Confectioner Stampile De Cauciuc, Metal, Facsimile",
        "Gravor Manual",
        "Tintuitor",
        "Bijutier Metale Comune",
        "Giuvaergiu",
        "Slefuitor Diamante Naturale",
        "Aplicator De Detalii La Produse Din Ceramica",
        "Debavurator-Retusor La Produse Din Ceramica Fina",
        "Turnator Produse Ceramice",
        "Fasonator Produse Ceramice",
        "Glazurator Produse Din Ceramica Fina",
        "Modelator Ceramica",
        "Olar Ceramica (Artizanat)",
        "Preparator Mase Ceramice",
        "Presator Produse Ceramice",
        "Rasnitor Smalt",
        "Slefuitor Produse Din Ceramica Fina",
        "Brigadier La Fabricarea Sticlei",
        "Modelator Tuburi Spectrale",
        "Tragator, Slefuitor, Gradator Nivele",
        "Prelucrator Topitura Sticla La Presa",
        "Prelucrator Topitura Sticla La Teava",
        "Formator Tuburi Spectrale",
        "Pictor Decor",
        "Gradator Vase Si Aparate De Laborator",
        "Gravor Produse De Sticla",
        "Inscriptioner Pe Produse De Sticla Si Ceramica",
        "Pictor Pe Sticla Si Ceramica",
        "Oglindar",
        "Confectioner Piese, Linguri, Spite, Albii, Donite, Cozi De Unelte, Sindrila, Ciubere",
        "Confectioner Jucarii",
        "Confectioner Obiecte Artizanale Din Lemn",
        "Confectioner Plute",
        "Confectioner Garnituri Pentru Etansare",
        "Pirogravor",
        "Ramar Poleitor",
        "Sculptor In Lemn",
        "Confectioner Creta Scolara",
        "Traforator Manual Lemn",
        "Dogar Manual",
        "Rotar Caretas",
        "Lumanarar",
        "Confectioner Cutite, Brice, Bratari, Andrele, Agrafe, Inele",
        "Confectioner Nasturi, Piepteni",
        "Confectioner Obiecte Casnice Din Deseuri De Aluminiu Si Alte Metale",
        "Confectioner Obiecte Din Ipsos",
        "Confectioner Obiecte Din Os, Scoica, Mica Etc.",
        "Confectioner Corzi Din Intestine",
        "Incadrator Tablouri",
        "Confectioner Materiale Didactice Pentru Stiintele Naturii",
        "Confectioner Bidinele, Pensule, Perii",
        "Confectioner Maturi",
        "Impletitor De Nuiele",
        "Impletitor Obiecte Din Foi De Porumb",
        "Impletitor Papura",
        "Legator De Par",
        "Sortator, Spalator Par",
        "Prelucrator De Par La Masina",
        "Prelucrator Manual De Par",
        "Impletitor Din Panglica Impletita",
        "Pieptanator De Par La Masina",
        "Fierbator-Uscator De Par",
        "Confectioner Plase Pescaresti",
        "Confectioner Articole Hartie",
        "Confectioner Bibelouri Din Jenille",
        "Decorator In Piele",
        "Velator-Matisor",
        "Confectioner Manual De Produse Din Sfori Sau Franghii",
        "Ghemuitor",
        "Polierator Franghii",
        "Cablator Franghii",
        "Saluzitor Franghii",
        "Confectioner Unelte Pescuit Din Plase",
        "Confectioner Imbracare Volane In Piele",
        "Prelucrator De Fulgi Si Pene",
        "Filator",
        "Ajutor Maistru Filator",
        "Tesator",
        "Tricoter Manual",
        "Ajutor Maistru Tesator, Tricoter",
        "Crosetor",
        "Impletitor Textile",
        "Confectioner Presuri",
        "Tesator Restaurator Manual Covoare",
        "Pregatitor Si Confectioner Cataloage Mostre",
        "Confectioner Tricotaje Dupa Comanda",
        "Finisor Textile (Vopsitor, Imprimeur)",
        "Repasator",
        "Aburitor Textile",
        "Reparator Covoare",
        "Tesator Manual",
        "Cusator Manusi Piele",
        "Croitor Manusi Piele",
        "Finisor Manusi Piele",
        "Croitor-Stantator Articole Marochinarie",
        "Cusator Articole Marochinarie",
        "Pregatitor Articole Marochinarie",
        "Asamblator-Montator Articole Marochinarie",
        "Confectioner Manual In Metaloplastie",
        "Confectioner Proteze Dentare",
        "Confectioner Proteze Ortopedice",
        "Confectioner Jaluzele",
        "Impletitor Fibre Plastice",
        "Confectioner Flori Artificiale",
        "Culegator La Masina De Cules Si Turnat Randuri (Linotipist)",
        "Culegator La Masina De Perforat Programe Pentru Masinile De Turnat Text (Monotastor)",
        "Culegator La Masina De Turnat Randuri Pentru Titluri (Ludlov)",
        "Culegator Manual (Zetar)",
        "Frezor-Montator Clisee",
        "Stereotipar",
        "Galvanotipist",
        "Corodor Prin Procedee Chimice (Tiefdruc Si Zinco)",
        "Zincograf",
        "Copist Formare Tipar Plan",
        "Desenator Cromolitograf",
        "Slefuitor-Granulator",
        "Gravor Placi Metalice",
        "Gravor Placi Litografice",
        "Fotogravor",
        "Turnator Valuri",
        "Manipulant Cutter-Plotter",
        "Tipograf Turnator La Masinile De Turnat Text",
        "Imprimeur Textil",
        "Imprimator Serigraf",
        "Taietor Matrite Serigrafie",
        "Serigraf",
        "Operator Presa De Transfer Termic",
        "Tipograf-Tiparitor",
        "Dactilo-Rotaprint",
        "Operator La Masina Electronica De Gravat",
        "Operator La Masinile De Fotoculegere (Monofoto)",
        "Operator Tiparituri Braille",
        "Heliografist",
        "Operator Xerox",
        "Operator Masini Multiplicat",
        "Tipograf Print Digital Si Offset",
        "Operator La Masina De Gravat Si Decupat Cu Laser",
        "Operator La Masina De Tampografiat",
        "Tipograf Flexograf",
        "Legator Manual (In Poligrafie Si Ateliere Speciale)",
        "Colator Publicitar",
        "Masinist In Legatorie Mecanica",
        "Strungar Slefuitor Tipografie",
        "Electrician In Constructii",
        "Electrician De Intretinere In Constructii",
        "Instalator Pentru Sisteme Fotovoltaice Solare",
        "Instalator Pentru Sisteme Termice Solare",
        "Montator Instalatii Solare",
        "Electrician Constructor Montator Aparataj Si Cabluri De Joasa Tensiune",
        "Electrician Constructor Montator Aparataj Si Cabluri De Medie Si Inalta Tensiune",
        "Electrician Constructor Instalator Aparatura De Masura Si Control",
        "Electrician Constructor Pentru Probe Si Incercari Functionale",
        "Electrician In Constructii Civile Si Industriale",
        "Electrician Echipamente Electrice Si Energetice",
        "Bobinator Aparataj Electric",
        "Electromecanic Reparator Obiecte De Uz Casnic",
        "Bobinator Masini Electrice Rotative",
        "Electrician Aparate Masura-Control Si Automatizare In Centrale Termoelectrice Si Nuclearoelectrice",
        "Electrician Montare Si Reparatii Aparataj Electric De Protectie, Relee, Automatizare",
        "Bobinator Condensatori Pentru Instalatii Electrice",
        "Electrician Verificari Si Masuratori Electrice In Centrale Si Retele Electrice",
        "Bobinator Transformatoare",
        "Montator/Reglor/Depanator De Aparataj Electric",
        "Montator, Reglor Si Depanator Pentru Aparate De Masura Electrice Si Relee",
        "Montator, Reglor Si Depanator De Ascensoare",
        "Electrician Nave",
        "Confectioner Cablaje Auto",
        "Electromecanic Masini Si Echipamente Electrice",
        "Electromecanic Statie Pompare Apa-Canal",
        "Electrician Exploatare Centrale Si Statii Electrice",
        "Electrician Exploatare Retele Electrice",
        "Electrician Montare Si Reparatii Cabluri Electrice Subterane",
        "Electrician Montare Si Reparatii Linii Electrice Aeriene",
        "Electrician Montare Si Reparatii Echipament Electric Din Centrale, Statii Si Posturi De Transformare",
        "Electrician Protectie Relee, Automatizari Si Masuratori Electrice",
        "Electrician De Intretinere Si Reparatii",
        "Electrician Montator De Instalatii Automatizate",
        "Electrician Montator De Instalatii Electrice La Mijloace De Transport",
        "Electrician Pentru Protectia Catodica",
        "Electrician Rural",
        "Electrician De Mina",
        "Electrician Pentru Utilizarea Energiei Electrice",
        "Electrician Depanator Utilaje Calcul",
        "Electronist Depanator Utilaje Calcul",
        "Plantator Elemente Electronice",
        "Operator In Verificarea, Intretinerea Si Repararea Instalatiilor Speciale De Prevenire A Incendiilor",
        "Tehnician Pentru Sisteme Si Instalatii De Semnalizare, Alarmare Si Alertare In Caz De Incendiu",
        "Tehnician Pentru Sisteme Si Instalatii De Limitare Si Stingere A Incendiilor",
        "Automatist",
        "Electromecanic Scb (Semnalizare, Centralizare, Blocare)",
        "Electromecanic Radio-Radioficare",
        "Electromecanic Retele Cabluri",
        "Electromecanic Retele Linii",
        "Electromecanic Telegrafie, Telefonie",
        "Electronist Telecomunicatii",
        "Jonctor",
        "Linior",
        "Montator, Reglor, Testor Aparatura De Telecomunicatii Si Instalatii De Semnalizare, Centralizare Si Blocare",
        "Electromecanic Electroalimentare",
        "Muncitor Radioelectronist",
        "Electromecanic Automatizari Si Telecomunicatii",
        "Electromecanic",
        "Carmangier",
        "Ciontolitor Transator Carne",
        "Macelar",
        "Sterilizator",
        "Taietor Pasari",
        "Lucrator La Prelucrarea Pestelui",
        "Afumator Carne",
        "Brutar",
        "Cofetar",
        "Patiser",
        "Preparator De Semifabricate Si Preparate Culinare",
        "Operator La Fabricarea Produselor Congelate De Patiserie Si Panificatie",
        "Pasteurizator Produse Lactate",
        "Preparator Produse Lactate",
        "Smantanitor",
        "Preparator Conserve, Legume Si Fructe",
        "Uscator-Deshidrator Legume, Fructe",
        "Preparator Castane, Dovleac, Porumb",
        "Lucrator In Procesarea De Fructe De Padure Si Ciuperci De Padure",
        "Degustator",
        "Conditioner Tutun Pentru Fabricarea Tigaretelor",
        "Vopsitor Lemn",
        "Pregatitor Paste Chimice",
        "Pregatitor Placi Fibrolemnoase Si Hartie Pentru Filme",
        "Uscator, Aburitor Material Lemnos",
        "Tamplar Universal",
        "Tamplar Carosier",
        "Tamplar Manual/Artizanal",
        "Marangoz-Calafatuitor",
        "Asamblator Lazi",
        "Confectioner-Montator Produse Din Lemn",
        "Curbator-Montator Butoaie Din Lemn",
        "Tamplar Manual La Presare Si Incleiere",
        "Corhanitor",
        "Tamplar Manual Ajustor Montator",
        "Tamplar Manual La Imbinarea Furnirelor",
        "Marangoz Cala-Tachelagiu",
        "Slefuitor, Lustruitor",
        "Pregatitor Suprafete Pentru Lacuit",
        "Gardinator",
        "Confectioner-Montator Cercuri La Butoaie",
        "Decupator Lamele Din Lemn Pentru Lazi",
        "Preparator-Dozator Adezive, Rasini, Lacuri Si Emailuri In Industria Lemnului",
        "Tamplar Restaurator",
        "Restaurator Sarpante Si Structuri Din Lemn",
        "Tamplar Binale",
        "Strungar In Lemn",
        "Reglor Masini De Prelucrat Lemn",
        "Taietor De Precizie In Lemn",
        "Confectioner Articole Speciale Din Lemn",
        "Confectioner Parchete",
        "Confectioner Cutii Chibrituri Din Furnir",
        "Impregnator-Uscator Chibrituri",
        "Confectioner Gamalii Chibrituri",
        "Masinist La Umplerea Si Inchiderea Cutiilor De Chibrituri",
        "Pastator Cutii De Chibrituri",
        "Fasonator Calapoade",
        "Montator Accesorii Pentru Calapoade",
        "Finisor Calapoade",
        "Circularist La Taiat Lemne De Foc",
        "Curbator Lemn",
        "Gradator Rechizite Si Articole Tehnice Din Lemn",
        "Tamplar Mecanic La Croit Si Dimensionat",
        "Tamplar Mecanic La Rindeluit",
        "Tamplar Mecanic La Frezat Si Gaurit",
        "Tamplar Mecanic La Strunjit",
        "Tamplar Mecanic La Slefuit",
        "Confectioner Mine Pentru Creioane",
        "Innobilator Scandurele Pentru Creioane",
        "Fasonator Creioane Si Tocuri",
        "Finisor Creioane Si Tocuri",
        "Preparator Paste Chimice Pentru Chibrituri",
        "Confectioner Cutii Chibrituri Din Carton",
        "Operator La Masini Unelte Cu Comanda Numerica In Prelucrarea Lemnului",
        "Croitor",
        "Lenjer, Confectioner Lenjerie Dupa Comanda",
        "Confectioner Palarii",
        "Ajutor Maistru Croitor",
        "Plior Confectii",
        "Modista",
        "Ceaprazar-Sepcar",
        "Curatitor-Reparator Palarii",
        "Retusier Confectii",
        "Blanar-Confectioner Imbracaminte Din Blana, Dupa Comanda",
        "Confectioner Imbracaminte Din Piele Si Inlocuitori, Dupa Comanda",
        "Cojocar",
        "Confectioner, Prelucrator In Industria Textila",
        "Croitor-Confectioner Imbracaminte, Dupa Comanda",
        "Multiplicator Sabloane Croitorie",
        "Confectioner Corsete",
        "Confectioner Reparator Cravate",
        "Planimetror Sabloane",
        "Croitor Confectioner Costume Teatru",
        "Broder Manual",
        "Stopeur",
        "Remaieur Ciorapi",
        "Broder Manual-Mecanic",
        "Broder La Gherghef",
        "Tapiter",
        "Saltelar",
        "Plapumar",
        "Mestesugar Argasitor",
        "Mestesugar Cenuseritor",
        "Mestesugar Finisor Mineral",
        "Mestesugar Finisor Vegetal",
        "Mestesugar Sortator In Industria Pielariei",
        "Cizmar-Confectioner Incaltaminte, Dupa Comanda",
        "Confectioner Articole Din Piele Si Inlocuitori",
        "Confectioner Incaltaminte Ortopedica",
        "Curelar, Confectioner Harnasamente",
        "Marochiner-Confectioner Marochinarie, Dupa Comanda",
        "Opincar",
        "Talpuitor (Confectioner-Reparatii Incaltaminte)",
        "Scafandru",
        "Scafandru Lucrator Subacvatic",
        "Scafandru Sef Grup",
        "Scafandru Sef Utilaj",
        "Scafandru Greu",
        "Operator Barocamera",
        "Scafandru Salvator",
        "Sef De Scufundare",
        "Tehnician De Scufundare",
        "Artificier De Mina",
        "Artificier La Lucrari De Suprafata",
        "Pirotehnician Cinematografie Si Teatru",
        "Controlor Calitate",
        "Miner In Subteran",
        "Miner La Suprafata",
        "Miner In Subteran Pentru Constructii",
        "Masinist Pentru Utilaje Specifice La Extractie Si Executia Tunelurilor",
        "Semnalist-Cuplator",
        "Excavatorist Pentru Excavatoare Cu Rotor De Mare Capacitate",
        "Trolist",
        "Brichetator Carbune",
        "Distilator La Prepararea Carbunelui",
        "Operator La Prepararea Minereurilor",
        "Operator La Sfaramarea Minereurilor",
        "Prajitor Minereu",
        "Prelucrator Mica",
        "Spalator La Prepararea Carbunilor",
        "Flotator La Prepararea Carbunilor",
        "Separator La Prepararea Carbunilor",
        "Morar La Masini De Maruntit Roci",
        "Tocator La Masini De Maruntit Roci",
        "Concasorist",
        "Operator Mineralurg",
        "Operator Extractie Titei",
        "Sondor La Foraj Manual",
        "Operator-Prospector Lucrari Geologice Si Geofizice",
        "Operator Transport Pe Conducte Singulare Gaze",
        "Operator Extractie Gaze",
        "Operator Extractie Titei In Subteran",
        "Operator Extractie Sare In Salina",
        "Operator Masuratori Speciale Sonde",
        "Operator Lucrari Speciale Sonde",
        "Sondor La Forajul Mecanizat Si Reparatii Sonde",
        "Sondor La Interventii De Sonde",
        "Sondor La Punerea In Productie",
        "Primitor-Preparator Produse Fluide",
        "Operator Flotare Produse Fluide",
        "Cuptorar Lianti",
        "Fasonator Produse Din Azbociment",
        "Finisor Produse Din Azbociment",
        "Morar Lianti",
        "Preparator Pasta De Azbociment",
        "Tratamentist Produse Din Azbociment",
        "Operator La Impregnarea Produselor Hidroizolatoare",
        "Masinist Pentru Prefabricate Din Beton Si Beton Armat",
        "Operator La Fabricarea Vatei Si Produselor Din Vata Minerala",
        "Confectioner Garnituri Din Azbest",
        "Cocsar",
        "Furnalist",
        "Otelar",
        "Pregatitor Materiale De Sarje",
        "Melanjorist",
        "Operator Oxizi De Plumb",
        "Dezbatator Lingouri",
        "Metalurgist Pulberi Din Oxid De Fier",
        "Curatitor Lingouri",
        "Preparator La Concentratele Miniere",
        "Topitor La Concentrate Miniere",
        "Rafinator Metale Neferoase",
        "Electrometalurgist",
        "Conditioner-Finisor",
        "Turnator Fonta",
        "Granulator Zgura",
        "Epurator Gaze",
        "Masinist Suflante",
        "Pregatitor De Sarje",
        "Dozator La Producerea Aglomeratului",
        "Aglomeratorist",
        "Masinist Exhaustor",
        "Operator Separare Magnetica",
        "Laminator Semifabricate, Profiluri Tabla Si Platbanda",
        "Laminator, Presator Tevi Plumb",
        "Topitor, Turnator Metale Pretioase",
        "Laminator Sarma",
        "Laminator Tabla Subtire",
        "Laminator De Bandaje Si Discuri",
        "Laminator De Tevi",
        "Laminator Pe Laminoare Continue",
        "Laminator De Benzi La Rece",
        "Presator De Tevi La Cald Si Profiluri Prin Extruziune",
        "Alimentator-Incalzitor De Materiale",
        "Operator La Cuptoare Si Instalatii Pentru Turnarea Si Laminarea Metalelor",
        "Laminator",
        "Termist-Tratamentist De Produse Brute, Forjate, Turnate Sau Laminate",
        "Termist Tratamentist De Piese Semifabricate, Finite",
        "Calitor Prin Inductie Sau Cu Flacara",
        "Calitor Scule",
        "Termist-Tratamentist",
        "Operator La Instalatii De Tratament Termic Cu Procesare",
        "Operator La Pregatirea Sarjelor Pentru Tratament Termic",
        "Finisor Laminate Si Trefilate",
        "Decapator",
        "Regulator Tevi",
        "Trefilator, Tragator",
        "Galvanizator",
        "Metalizator Prin Pulverizare",
        "Metalizator Prin Cufundare In Metal Topit",
        "Confectioner Protectii Si Obiecte Anticorozive",
        "Emailator",
        "Operator La Confectionarea Materialelor Electroizolante",
        "Matisor Cabluri",
        "Metalizator-Termist",
        "Arzator Email",
        "Emailator Insigne Si Decoratii",
        "Emailator Firme Si Decoruri",
        "Emailator Prin Pudrare",
        "Emailator Prin Pulverizare",
        "Preparator Email",
        "Emailator Prin Imersiune",
        "Acoperitor Metale",
        "Poleitor Filiere",
        "Protejator Conductori Cabluri Si Condensatori Statici De Forta",
        "Confectioner Izolatii La Conductori Electrici",
        "Confectioner Mantale De Plumb Prin Presare La Cabluri",
        "Confectioner Toroane Si Cablaje La Conductori Electrici",
        "Pregatitor Seturi De Cabluri Electrice Pentru Autotrac Si Accesorii",
        "Preparator Electrolit Si Amestec Depolarizator",
        "Confectioner Si Legator Depolarizator",
        "Asamblator Elemente Si Baterii Galvanice",
        "Confectioner De Elemente Galvanice",
        "Confectioner Celule De Electroliza",
        "Operator La Masini De Macinare Fina (Produse Chimice)",
        "Operator La Masini De Fragmentare (Produse Chimice)",
        "Operator La Masini De Amestecare (Produse Chimice)",
        "Operator La Instalatii De Ardere",
        "Uscator In Industria Chimica",
        "Preparator In Industria Chimica",
        "Sinterizator",
        "Operator La Fabricarea Sticlei",
        "Impaslitor Panza Sticla",
        "Filator Fibre Sticla",
        "Preparator Amestec Si Topitor Sticla",
        "Operator Poliesteri Armati Cu Fibra De Sticla",
        "Extractorist In Chimie",
        "Fermentator In Chimie",
        "Concentrator-Purificator In Chimie",
        "Extractorist Uleiuri Volatile Naturale Si Colesterina",
        "Operator Chimist La Producerea Compusilor Organici Ai Sulfului Si Ingrasamintelor Fosfatice",
        "Distilator In Industria Chimica",
        "Operator Chimist La Producerea Diverselor Produse Anorganice",
        "Operator Chimist La Fabricarea Lacurilor, Vopselelor Si Uleiurilor",
        "Operator Chimist La Fabricarea Colorantilor",
        "Operator La Obtinerea Produselor Din Spume Poliuretanice Si Latex",
        "Operator Chimist La Producerea Compusilor Anorganici Ai Azotului Si Ingrasamintelor Azotoase",
        "Operator Lacuri Electroizolante",
        "Preparator Lacuri, Vopsele, Paste De Fludor Folosite La Aparataj Electric",
        "Operator Chimist La Chimizarea Gazelor De Rafinarie",
        "Operator Cracare, Deformare Si Fabricare Bitum",
        "Operator Chimist La Fabricarea Altor Produse Organice",
        "Operator Chimist La Chimizarea Gazului De Cocs",
        "Producator De Fire Si Fibre Sintetice",
        "Operator La Fabricarea Pieii Sintetice",
        "Preparator Ferodouri",
        "Finisor Universal Ferodouri",
        "Operator La Fabricarea Glicerinei Si Acizilor Grasi",
        "Operator La Fabricarea Sapunurilor",
        "Operator La Produse Odorante Sintetice",
        "Operator La Fabricarea Detergentilor",
        "Operator Chimist La Produsele Farmaceutice Si Chimice Pure",
        "Preparator Benzi Cauciucate Si Compozitii Emplastre",
        "Preparator Prafuri De Spalat Si Curatat",
        "Preparator La Prepararea Produselor Cosmetice Si De Parfumerie",
        "Preparator Ser Vaccin",
        "Conditioner Finisor Produse Explozive",
        "Confectioner Fitile",
        "Confectioner Produse Pirotehnice",
        "Nitrator",
        "Pregatitor La Produse Explozive",
        "Preparator La Produse Explozive",
        "Confectioner Cartuse De Vanatoare",
        "Operator La Tragere Si Munitie",
        "Operator La Pregatirea, Conservarea Si Ambalarea Armamentului Si Munitiei",
        "Pregatitor, Completator De Echipamente Tehnice Si Sdv-Uri",
        "Delaborator Munitie",
        "Operator La Producerea Sodei Si Produselor Clorosodice",
        "Operator La Fabricarea Altor Produse Chimice",
        "Fotoceramist",
        "Fotocopist",
        "Fotopoligraf",
        "Fotoreproducator",
        "Montator Filme",
        "Retusor Clisee",
        "Pregatitor Hartie Fotosensibila",
        "Operator La Fabricarea Filmelor Fotografice",
        "Preparator La Confectionarea Produselor Industriale Din Cauciuc",
        "Pregnator Prize Tehnice Si Banda Izolatoare",
        "Confectioner De Produse Industriale Din Cauciuc",
        "Vulcanizator De Produse Industriale Din Cauciuc",
        "Finisor-Reparator De Produse Industriale Din Cauciuc",
        "Operator La Prelucrarea Cauciucului",
        "Confectioner Garnituri De Etansare Din Cauciuc",
        "Finisor Incaltaminte Si Articole Tehnice Din Cauciuc",
        "Calandror La Finisarea Cauciucului",
        "Pregatitor Regenerare Cauciuc",
        "Devulcanizator Regenerare Cauciuc",
        "Rafinator Regenerare Cauciuc",
        "Dozator Prelucrare Cauciuc",
        "Impregnator Produse Din Cauciuc",
        "Profilator Produse Din Cauciuc",
        "Stantator Piese Pentru Incaltaminte Din Piele Si Cauciuc",
        "Cusator Piese La Incaltaminte Din Cauciuc",
        "Vulcanizator Piese Din Cauciuc La Prese",
        "Vulcanizator La Autoclava",
        "Preparator Cauciuc Electroizolant",
        "Valtar Cauciuc Electroizolant",
        "Masinist La Confectionarea Materialelor Electroizolante Impregnate",
        "Masinist La Confectionarea Materialelor Electroizolante Stratificate (Mica)",
        "Masinist La Confectionarea Foliilor De Cauciuc Electroizolante",
        "Presator-Formator Materiale Stratificate, Pregnator Prize Tehnice Si Banda Izolatoare",
        "Conditioner-Finisor Produse Din Cauciuc",
        "Croitor Pentru Incaltaminte Si Articole Tehnice Din Cauciuc",
        "Pregatitor Pentru Incaltaminte Si Articole Tehnice Din Cauciuc",
        "Preparator Placi De Etansare Comprimate",
        "Operator Fabricarea Si Prelucrarea Polimerilor",
        "Preparator Mase Plastice",
        "Valtar Calandru Mase Plastice",
        "Operator La Prelucrarea Maselor Plastice",
        "Presator Mase Plastice",
        "Finisor-Asamblator Obiecte Din Mase Plastice",
        "Creator, Modelier Mase Plastice",
        "Operator La Confectionarea Discurilor Fonografice",
        "Operator Sudare Tevi Si Fitinguri Din Polietilena De Inalta Densitate Pehd",
        "Operator Mase Plastice",
        "Operator Masini De Termoformatare",
        "Cartonagist",
        "Operator La Masina De Laminat",
        "Decapsulator",
        "Decuscutor",
        "Topitor In Si Canepa",
        "Melitator In Si Canepa",
        "Innobilator In Si Canepa",
        "Scuturator In Si Canepa",
        "Lucrator In Bataje (Batator)",
        "Destramator",
        "Carbonizator Textile",
        "Scuturator",
        "Pregatitor Amestecuri In Filaturi",
        "Cardator",
        "Laminator Benzi Din Fibre",
        "Pieptanator",
        "Zdrobitor Si Uleiator Textile",
        "Operator Masini Puitoare",
        "Formator Manusi Fibre Liberiene",
        "Montator La Lipit Ace",
        "Curatitor-Slefuitor Garnituri Carde",
        "Cilindror In Filaturi",
        "Disponent In Filaturi",
        "Pregatitor Gogosi De Matase (Fierbator)",
        "Prelucrator Fire De Matase Din Gogosi (Filator)",
        "Innodator Fire De Matase Naturala",
        "Finisor Fire De Matase Naturala",
        "Prelucrator Deseuri Gogosi De Matase Naturala",
        "Operator La Masini De Tricotat Rectiliniu",
        "Operator La Deservirea Razboaielor De Tesut",
        "Snuruitor Jaqard",
        "Operator La Masini De Tricotat Circular",
        "Operator Sculuitor",
        "Operator Canelator",
        "Operator La Masini De Urzit",
        "Operator Incheietor Fire",
        "Operator Navaditor, Lipitor, Innodator Fire",
        "Operator Bobinator-Dublator",
        "Operator Batirator Fire",
        "Operator Rasucitor Fire",
        "Paslitor",
        "Confectioner Polizoare Din Pasla",
        "Operator Confectioner Industrial Imbracaminte Din Tesaturi, Tricotaje, Materiale Sintetice",
        "Operator Confectii Imbracaminte Din Piele Si Inlocuitori",
        "Operator La Confectionarea Industriala A Imbracamintei Din Blana",
        "Operator La Confectionarea Industriala A Manusilor Din Piele",
        "Incadrator Confectii",
        "Rihtuitor Confectii",
        "Pregatitor-Lansator Confectii",
        "Spanuitor Confectii",
        "Taietor Confectii",
        "Operator Gazator Textile",
        "Operator Descleietor Textile",
        "Operator Degamator Textile",
        "Operator Spalator Textile",
        "Operator Albitor Textile",
        "Operator Fierbator Textile",
        "Operator Mercerizator Textile",
        "Operator Pregatitor Chimicale In Industria Textila",
        "Operator Vopsitor Textile",
        "Operator Imprimeur Textile",
        "Confectioner Sabloane Si Cilindri De Imprimat",
        "Operator Apretor Textile",
        "Operator Calandor-Govrator Textile",
        "Operator Impregnator Textile",
        "Operator Decator",
        "Operator Presator Tesaturi Textile (Storcator Textile)",
        "Operator Fixator Textile",
        "Operator Piuar",
        "Operator Scamosetor",
        "Operator Tunsator Textile",
        "Operator Curatitor Chimic",
        "Operator Metrar-Volator-Dublator Textile",
        "Operator Taietor Textile",
        "Operator Uscator Textile",
        "Operator Ingreunator Matase Naturala",
        "Naphtolator La Imprimerie",
        "Vaporizator La Imprimerie",
        "Confectioner Sabloane La Imprimerie",
        "Presator Axe La Cilindrul De Imprimat",
        "Operator Universal ",
        "Operator Cenuseritor",
        "Operator Tabacitor Mineral Argasitor",
        "Operator Tabacitor Vegetal",
        "Operator Finisor Mineral",
        "Operator Finisor Vegetal",
        "Operator Argasitor",
        "Operator Sortator In Industria Pielariei",
        "Vopsitor Imbracaminte Din Blana",
        "Operator La Prepararea Talpii De Incaltaminte Din Fibre",
        "Operator La Confectionarea Industriala A Articolelor Din Cauciuc Si Textile Cauciucate",
        "Croitor-Stantator Piese Incaltaminte",
        "Pregatitor Piese Incaltaminte",
        "Cusator Piese Din Piele Si Inlocuitori",
        "Tragator Fete Pe Calapod",
        "Talpuitor Industrial",
        "Finisor Incaltaminte",
        "Operator La Confectionarea Industriala A Palariilor",
        "Croitor Confectii Industriale Din Blana",
        "Operator La Confectionarea Industriala A Articolelor De Sport Si Protectie, Din Piele Si Inlocuitori",
        "Cusator Confectii Industriale Din Blana",
        "Pregatitor Confectii Industriale Din Blana",
        "Finisor Confectii Industriale Din Blana",
        "Operator Textile Netesute",
        "Operator La Prepararea Conservelor Din Carne, Peste Si In Amestec Legume Si Peste",
        "Operator La Valorificarea Subproduselor De Abator",
        "Tripier",
        "Preparator Peste, Raci, Broaste In Cherhanale Si Oficii",
        "Preparator Faina Din Peste",
        "Topitor Grasimi Comestibile Si De Uz Industrial",
        "Operator La Fabricarea Mezelurilor",
        "Colector Si Sortator Par",
        "Preparator Ulei De Copite",
        "Colector Si Preparator Faina, Sange, Carne, Oase",
        "Curatitor Piei",
        "Valorificator Glande",
        "Preparator Pepsina, Cheag",
        "Matar",
        "Operator La Prepararea Branzeturilor",
        "Operator La Prepararea Produselor Lactate",
        "Operator Centru De Racire Lapte",
        "Operator La Fabricarea Untului",
        "Preparator Conserve Lapte Si Lactoza",
        "Morar",
        "Operator La Fabricarea Nutreturilor Combinate",
        "Preparator Boia De Ardei",
        "Preparator Mustar",
        "Preparator Extracte, Arome Si Esente",
        "Decorticator Crupe",
        "Operator La Prepararea Produselor Zaharoase",
        "Operator La Fabricarea Produselor Fainoase",
        "Preparator Inghetata",
        "Operator La Fabricarea Biscuitilor",
        "Preparator Napolitane",
        "Operator La Fabricarea Uleiurilor Vegetale",
        "Operator La Fabricarea Conservelor Din Legume Sau Fructe",
        "Operator La Fabricarea Zaharului",
        "Conditioner Miere",
        "Preparator De Produse Apicole",
        "Preparator Surogate Cafea",
        "Operator La Conditionarea Si Prelucrarea Plantelor Medicinale",
        "Operator La Fermentarea Tutunului Si Fabricarea Produselor Din Tutun",
        "Preparator Halva",
        "Operator La Prepararea Bauturilor Alcoolice Si Racoritoare",
        "Operator La Fabricarea Berii",
        "Operator La Fabricarea Maltului",
        "Operator La Fabricarea Spirtului Si Drojdiei De Panificatie",
        "Vinificator-Pivnicer",
        "Fermentator Otet",
        "Operator La Fabricarea Glucozei",
        "Preparator Bauturi Racoritoare",
        "Preparator Rachiuri Industriale Si Lichioruri",
        "Distilator Rachiuri Naturale",
        "Operator La Fabricarea Amidonului Si Dextrinei",
        "Preparator Coniac",
        "Preparator Vermut",
        "Preparator Sampanie",
        "Pregatitor Lemn, Stuf, Paie",
        "Preparator Pasta",
        "Fierbator-Spalator Celuloza, Hartie",
        "Albitor Pasta Hartie",
        "Confectioner Tambur Filigranare",
        "Masinist La Deshidratare Pasta Hartie",
        "Finisor Hartie, Carton, Mucava",
        "Confectioner Produse Igienico-Sanitare",
        "Confectioner Rondele Din Pluta",
        "Confectioner Bastoane Din Pluta",
        "Confectioner Colaci Si Centuri De Salvare",
        "Masinist La Masina De Taiat Sraifuri Si Dopuri Din Pluta",
        "Masinist La Masina De Zdrobit Si Macinat Pluta",
        "Confectioner Placi Izolatoare",
        "Aburitor Pluta",
        "Pregatitor Lemn Aschietor",
        "Pregatitor Aschii",
        "Incleietor Placi Aglomerate",
        "Formator Presator Placi Brute",
        "Formator Finisor Placi",
        "Tocatorist-Defibratorist",
        "Filtrator-Deshidratorist",
        "Presator Pfl",
        "Tratamentist Pfl",
        "Formator Pfl",
        "Impregnator La Innobilare Pfl",
        "Fasonator-Sortator Filme",
        "Presator La Innobilare Pfl",
        "Formator La Innobilare Pfl",
        "Finisor La Innobilare Pfl",
        "Pregatitor Pfl Si Hartie Pentru Filme",
        "Gaterist La Taiat Busteni",
        "Taietor La Ferastrau Panglica",
        "Fasonator Cherestea",
        "Desenator-Insemnator Cherestea",
        "Decupator Furnire",
        "Derulatorist",
        "Fasonator-Uscator Furnire",
        "Frezor-Imbinator Furnire Tehnice",
        "Presator Produse Stratificate",
        "Formator Slefuitor Produse Stratificate",
        "Preparator Ppf",
        "Miezuitor Panele Si Placi Celulare",
        "Operator La Recoltarea Si Toaletarea Arborilor Forestieri",
        "Topitor Sticla",
        "Prelucrator De Topituri La Semiautomate",
        "Prelucrator De Topituri La Instalatii De Tras Tevi",
        "Prelucrator De Tuburi Si Baghete",
        "Cuptorar Recoacere Sticla",
        "Confectioner Termosuri",
        "Taietor Produse Din Sticla",
        "Slefuitor Produse Din Sticla",
        "Arzator Produse Din Sticla",
        "Sablator Produse Din Sticla",
        "Argintar Produse Din Sticla",
        "Operator La Instalatii Automate Pentru Prepararea Amestecului",
        "Operator La Instalatii Automate Pentru Prelucrarea Topiturii De Sticla",
        "Operator La Prelucrarea Tuburilor Din Sticla",
        "Operator La Masini De Inscriptionat",
        "Prelucrator Fire Si Tesaturi Din Fire De Sticla",
        "Operator La Instalatii De Tras Si Laminat Geam",
        "Turnator Geam",
        "Preparator Vata De Sticla",
        "Taietor Geam",
        "Slefuitor/ Sablator Geam",
        "Securizator Geam",
        "Pregatitor De Materii Prime Pentru Producerea Sticlei",
        "Strungar Produse Ceramice",
        "Cuptorar Ceramica Fina Si Decor",
        "Arzator Produse Ceramice",
        "Operator La Fabricarea Produselor Refractare",
        "Operator La Fabricarea Produselor Abrazive",
        "Operator La Fabricarea Produselor Din Carbune",
        "Operator Abrazive Pe Suporti",
        "Finisor Produse Abrazive",
        "Granulator/ Sortator Abrazive",
        "Cuptorar Produse Abrazive",
        "Preparator-Presator Abrazive",
        "Cuptorar Produse Refractare",
        "Formator Produse Refractare",
        "Preparator-Presator Produse Din Carbune",
        "Cuptorar Produse Din Carbune",
        "Finisor Produse Din Carbune",
        "Prelucrator Produse Ceramice Prin Extrudare",
        "Discuitor De Produse Ceramice La Masini",
        "Prelucrator Produse Ceramice Prin Injectare",
        "Armator De Izolatori Electrici (Prelucrator Produse Electrotehnice",
        "Fochist Locomotiva Cu Abur",
        "Fochist La Masini Cu Abur",
        "Masinist La Instalatii Pentru Incalzit Tren",
        "Fochist Pentru Cazane De Abur Si De Apa Fierbinte",
        "Ajutor Fochist",
        "Fochist Pentru Cazane Mici De Abur",
        "Fochist La Cazane De Apa Calda Si Cazane De Abur De Joasa Presiune",
        "Fochist Pentru Cazane Conduse De Calculator",
        "Masinist La Masini De Ambalat",
        "Operator La Masina De Etichetat",
        "Operator La Roboti Industriali",
        "Operator La Tratarea Si Epurarea Apelor Uzate",
        "Operator Instalatie De Sortare Si Reciclare Deseuri Menajere Si Asimilabile",
        "Operator Generatoare Terestre Sonice Si Cu Agent Activ De Insamantare",
        "Operator Punct De Lansare",
        "Pompagiu",
        "Compresorist",
        "Operator Montaj Linii Automate",
        "Lacatus Montator Pentru Utilaje Industriale, De Constructii Si Agricole",
        "Pregatitor Si Montator Utilaje Tehnologice",
        "Montator Subansamble",
        "Montator Aparate Aer Conditionat",
        "Operator Calitate Flux",
        "Lacatus-Montator Masini Electrice Rotative, Transformatoare Si Aparataj",
        "Confectioner Protectie Dielectrica Pentru Acumulatori",
        "Morar La Prepararea Materialelor Pentru Acumulatori",
        "Confectioner Gratare Si Accesorii Pentru Acumulatori",
        "Confectioner Placi Pentru Acumulatori",
        "Preparator Lesie Pentru Acumulatori",
        "Montator Acumulatori",
        "Confectioner Cabluri Si Arbori De Cabluri",
        "Montator-Reglor, Depanator Aparate Electronice, Telecomunicatii, Radio",
        "Confectioner Tuburi Cinescop",
        "Montator-Reglor, Depanator De Instalatii De Electronica Si Curenti",
        "Montator-Reglor, Depanator De Aparate Radio Si Tv, Redresoare Si",
        "Confectioner Piese Radio Si Semiconductori",
        "Confectioner Circuite Integrate",
        "Confectioner Scala Radio",
        "Confectioner Circuite Imprimate",
        "Montator, Reglor, Testor Tehnica De Calcul",
        "Confectioner Lampi Fluorescente",
        "Confectioner Lampi Cu Vapori De Mercur",
        "Confectioner Lampi Cu Vapori De Sodiu",
        "Confectioner Becuri",
        "Montator Electromecanic",
        "Asamblor Biciclete",
        "Asamblor Jucarii",
        "Asamblor Articole De Sport",
        "Operator La Fabricarea Fermoarelor",
        "Confectioner De Bete, Lansete, Manere Si Dopuri Pentru Unelte De Pescuit",
        "Confectioner-Asamblor Articole Din Lemn",
        "Confectioner-Asamblor Articole Din Carton",
        "Confectioner-Asamblor Articole Din Textile",
        "Montor Articole Din Piele",
        "Mecanic Locomotiva Si Automotor",
        "Mecanic Ajutor Locomotiva Si Automotor",
        "Conducator Autodrezina",
        "Mecanic Conducator Vagon Motor De Rectificare A Liniei Aeriene",
        "Mecanic Locomotiva Si Rama Electrica Metrou",
        "Mecanic Ajutor Locomotiva Si Rama Electrica Metrou",
        "Franar",
        "Manevrant Vagoane",
        "Sef Manevra",
        "Acar",
        "Sef Tren",
        "Paznic Bariera",
        "Revizor Ace",
        "Conducator De Motocicleta",
        "Conducator De Motoscuter",
        "Sofer De Autoturisme Si Camionete",
        "Sofer Autosanitara",
        "Sofer Autoambulanta",
        "Pilot Incercare Auto",
        "Sofer Autobuz",
        "Conducator Troleibuz",
        "Conducator Tramvai (Vatman",
        "Sofer Autocamion/ Masina De Mare Tonaj",
        "Sofer Transport Valori Bancare",
        "Lucrator Operativ Pentru Autocontainere",
        "Conducator Autospeciala",
        "Camionagiu",
        "Tractorist",
        "Combiner Agricol",
        "Motorist La Motoagregate Si Masini In Silvicultura",
        "Mecanic De Exploatare In Cultura Mare",
        "Mecanic De Exploatare In Zootehnie",
        "Operator La Colectatul Si Manipulatul Lemnului",
        "Masinist La Masini Pentru Terasamente (Ifronist",
        "Masinist La Instalatiile De Preparat Si Turnat Beton Si Mixturi Asfaltice",
        "Masinist La Masini Cale Mecanizare Usoara Si Grea",
        "Operator La Utilaje De Forjat Dirijat",
        "Operator La Utilaje De Reabilitari Conducte Subterane",
        "Operator La Utilaje Pentru Subtraversari",
        "Macaragiu",
        "Masinist Pod Rulant",
        "Funicularist",
        "Macaragiu Macarale Plutitoare",
        "Sofer Automacaragiu",
        "Supraveghetor Statie Senal Navigabil",
        "Funicularist, Funiculare Pasagere",
        "Mecanizator (Muncitor Portuar",
        "Liftier",
        "Docher",
        "Sef Echipa Docheri",
        "Docher Instalatii De Incarcare/ Descarcare La Bordul Navei Si Cheu",
        "Docher-Amarator",
        "Docher-Mecanizator",
        "Macaragiu Portuar",
        "Masinist La Masini Mobile Pentru Transporturi Interioare",
        "Masinist La Alte Masini Fixe De Transport Pe Orizontala Si Verticala",
        "Stivuitorist",
        "Tractorist Portuar",
        "Conducator Autotrailer",
        "Conducator Autoincarcator Portuar",
        "Stivuitorist Portuar",
        "Marinar, Pilot Naval, Barjist",
        "Observator Far Maritim Si Statie Semnal De Ceata",
        "Marinar Legator",
        "Conducator Ambarcatiuni Agrement Pe Ape Interioare",
        "Pontonier Feribot",
        "Servator Far Maritim Si Statie Semnal De Ceata",
        "Conducator De Salupa Maritima/ Fluviala",
        "Timonier Maritim/ Fluvial",
        "Motopompist",
        "Menajera",
        "Femeie De Serviciu",
        "Ingrijitor Spatii Hoteliere",
        "Lucrator Room-Service Hotel",
        "Calcatoreasa Lenjerie",
        "Curatatoreasa Lenjerie",
        "Spalatoreasa Lenjerie",
        "Spalator Covoare Innodate",
        "Spalator Vehicule",
        "Spalator Vitrine Si Geamuri",
        "Ingrijitor Animale",
        "Muncitor Manipulare Si Pregatire Furaje",
        "Muncitor Necalificat In Agricultura",
        "Vacar",
        "Ingrijitor Pomi",
        "Muncitor Necalificat In Silvicultura",
        "Taietor Manual Lemn De Foc",
        "Muncitor Necalificat In Pescuit Si Vanatoare",
        "Muncitor Piscicol",
        "Muncitor Necalificat In Mine Si Cariere",
        "Impingator Vagoneti",
        "Lucrator La Amenajarea Terenurilor Sportive (Amenajator Baza Sportiva)",
        "Ingrijitor Spatii Verzi",
        "Muncitor Necalificat La Intretinerea De Drumuri, Sosele, Poduri, Baraje",
        "Sapator Manual",
        "Muncitor Necalificat La Demolarea Cladirilor, Captuseli Zidarie, Placi",
        "Muncitor Necalificat La Spargerea Si Taierea Materialelor De Constructii",
        "Ambalator Manual",
        "Imbuteliator Fluide Sub Presiune",
        "Marcator Piese",
        "Muncitor Necalificat La Ambalarea Produselor Sub Forma De Praf Si",
        "Muncitor Necalificat La Ambalarea Produselor Solide Si Semisolide",
        "Muncitor Necalificat In Industria Confectiilor",
        "Muncitor Necalificat La Asamblarea, Montarea Pieselor",
        "Lucrator Sortator Deseuri Reciclabile",
        "Imbuteliator Gaz Petrol Lichefiat",
        "Muncitor In Activitatea De Gospodarire A Spanului",
        "Umplutor Sifoane",
        "Muncitor Necalificat In Metalurgie",
        "Caraus",
        "Incarcator-Descarcator",
        "Legator De Sarcina",
        "Manipulant Marfuri",
        "Operator Transport Si Distribuire Butelii De Gpl",
        "Muncitor Spalare Si Curatare Cisterne",
        "Muncitor In Serviciile De Trafic Aerian",
        "Lucrator Bucatarie (Spalator Vase Mari",
        "Lustragiu",
        "Spalator Geamuri Si Parbrize",
        "Vanzator Ambulant De Produse Nealimentare",
        "Vanzator De Ziare",
        "Lucrator Operativ Pentru Autocompactoare",
        "Lucrator Pentru Salubrizare Cai Publice",
        "Lucrator Pentru Salubrizare Spatii Verzi",
        "Lucrator Pentru Salubrizare",
        "Lucrator Utilaje Specializate Pentru Salubrizare",
        "Curier",
        "Hamal",
        "Comisioner",
        "Distribuitor Presa",
        "Ingrijitor Caini In Adaposturi",
        "Gropar",
        "Incinerator",
        "Prinzator Caini",
        "Cantaragiu",
        "Casier Incasator",
        "Incasator Si Cititor Contoare De Energie Electrica, Gaze, Apa",
        "Vidanjor-Curatitor Canale",
        "Operator Deratizare, Dezinsectie, Dezinfectie",
        "Model (Invatamant",
        "Gonaci",
        "Garderobier",
        "Ucenic",
        "Aprod",
        "Controlor Poarta",
        "Paznic",
        "Plasator",
        "Portar",
        "Supraveghetor Muzeu",
        "Supraveghetor Noapte (Invatamant)",
        "Supraveghetor Sali Spectacole",
        "Supraveghetor Hotel",
        "Operator Masini Insacuire Pentru Fabrica De Ciment",
        "Operator Masini Paletizate Si Infoliere Pentru Fabrica De Ciment",
        "Operator Fabricatie Flux",
        "Montator, Reglor Si Depanator De Aparate Si Echipamente Electronice",
        "Operator La Platforme Pentru Lucru La Inaltime",
        "Operator Umplere Recipiente Gpl",
        "Ajutor Bucatar",
    ]
